@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -218,12 +218,18 @@ static XtActionsRec actionsListBarrel[] =
 
 static XtResource resourcesBarrel[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(BarrelWidget, barrel.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(BarrelWidget, barrel.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(BarrelWidget, core.width),
+	 XtRString, (caddr_t) "512"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(BarrelWidget, core.height),
+	 XtRString, (caddr_t) "512"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(BarrelWidget, barrel.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -236,9 +242,6 @@ static XtResource resourcesBarrel[] =
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(BarrelWidget, barrel.tileColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultForeground*/},
-	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(BarrelWidget, barrel.borderColor),
-	 XtRString, (caddr_t) "gray50" /*XtDefaultBackground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(BarrelWidget, barrel.faceName[0]),
 	 XtRString, (caddr_t) "Green"},
@@ -257,33 +260,9 @@ static XtResource resourcesBarrel[] =
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(BarrelWidget, barrel.faceName[5]),
 	 XtRString, (caddr_t) "black"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(BarrelWidget, core.width),
-	 XtRString, (caddr_t) "512"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(BarrelWidget, core.height),
-	 XtRString, (caddr_t) "512"},
-	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
-	 XtOffset(BarrelWidget, barrel.tiles),
-	 XtRString, (caddr_t) "6"}, /* DEFAULTTILES */
-	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
-	 XtOffset(BarrelWidget, barrel.faces),
-	 XtRString, (caddr_t) "5"}, /* DEFAULTFACES */
-	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.orient),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
-	{XtNpairs, XtCPairs, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.pairs),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPAIRS */
-	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.practice),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.mono),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.reverse),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(BarrelWidget, barrel.borderColor),
+	 XtRString, (caddr_t) "gray50" /*XtDefaultBackground*/},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.install),
 	 XtRString, (caddr_t) "FALSE"},
@@ -305,15 +284,30 @@ static XtResource resourcesBarrel[] =
 	{XtNfont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(BarrelWidget, barrel.font),
 	 XtRString, (caddr_t) "9x15bold"},
+	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
+	 XtOffset(BarrelWidget, barrel.tiles),
+	 XtRString, (caddr_t) "6"}, /* DEFAULTTILES */
+	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
+	 XtOffset(BarrelWidget, barrel.faces),
+	 XtRString, (caddr_t) "5"}, /* DEFAULTFACES */
+	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.orient),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
+	{XtNpairs, XtCPairs, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.pairs),
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPAIRS */
+	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.practice),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.base),
 	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(BarrelWidget, barrel.cheat),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(BarrelWidget, barrel.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(BarrelWidget, barrel.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
@@ -323,6 +317,12 @@ static XtResource resourcesBarrel[] =
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.menu),
 	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.cheat),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(BarrelWidget, barrel.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -1180,8 +1180,8 @@ RotateTiles(BarrelWidget w, int start, int finish, int direction, int fast)
 	for (i = start; i <= finish; i++) {
 		currTile = w->barrel.tileOfPosition[r * w->barrel.tiles + i];
 		for (k = 1; k <= w->barrel.faces; k++) {
-			newR = (direction == TOP) ? (r +
-				w->barrel.faces - 1) % w->barrel.faces :
+			newR = (direction == TOP) ?
+				(r + w->barrel.faces - 1) % w->barrel.faces :
 				(r + 1) % w->barrel.faces;
 			pos = r * w->barrel.tiles + i;
 			newPos = newR * w->barrel.tiles + i;
@@ -1772,6 +1772,9 @@ UndoTiles(BarrelWidget w)
 			MoveShift(w, direction, DOUBLE);
 		} else if (MoveTilesDir(w, direction, tile, False, DOUBLE)) {
 			SetBarrel(w, BARREL_UNDO);
+			if (CheckSolved(w)) {
+				SetBarrel(w, BARREL_SOLVED);
+			}
 		} else {
 			char *buf1, *buf2;
 
