@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -84,108 +84,108 @@ static BarrelRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Barrel Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Barrel Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-tile {color}]\n"
-	"\t[-face{0|1|2|3|4|5} {color}] [-[no]orient] [-[no]pairs]\n"
-	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
-	"\t[-[no]sound] [-bumpSound {filename}] [-moveSound {filename}]\n"
-	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-face{0|1|2|3|4|5} {color}]\n"
+"[-{border|bd} {color}] [-[no]install]\n"
+"[-picture {filename}] [-delay msecs] [-[no]sound]\n"
+"[-bumpSound {filename}] [-moveSound {filename}]\n"
+"[-{font|fn} {fontname}] [-[no]orient] [-[no]pairs]\n"
+"[-base {int}] [-userName {string}] [-scoreFile {filename}]\n"
+"[-scores] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The Barrel, the Billion Barrel, or Wonderful Barrel also "
-	"seen as the Cylinder Puzzle of Japanese origin.  The puzzle\n"
-	"contains 23 beads of 6 different colors.  4 each of 5 "
-	"different colors arranged in 5 rows and 3 black beads making\n"
-	"3 rows one unit longer.  A system of plungers slide all "
-	"three of the long rows left and right.  Two of the plungers\n"
-	"sit together and the other (the middle plunger) is "
-	"separate from the other two.  There are 2 separate wheels or\n"
-	"disks that rotate about the center axis.\n"
+"The Barrel, the Billion Barrel, or Wonderful Barrel also "
+"seen as the Cylinder Puzzle of Japanese origin.  The puzzle\n"
+"contains 23 beads of 6 different colors.  4 each of 5 "
+"different colors arranged in 5 rows and 3 black beads making\n"
+"3 rows one unit longer.  A system of plungers slide all "
+"three of the long rows left and right.  Two of the plungers\n"
+"sit together and the other (the middle plunger) is "
+"separate from the other two.  There are 2 separate wheels or\n"
+"disks that rotate about the center axis.\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a tile. Release "
-	"\"mouse-left\" button in the same row would move the tile towards\n"
-	"the space (unless there is no space in that row).  "
-	"Release on a different row will move the tiles up or down.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle orient mode.  Slightly "
-	"more challenging on (default is off).\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to toggle the pairs mode.  All "
-	"the tiles rotate in pairs.  This is considerably\n"
-	"more challenging on (default is on).\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"the mouse.\n"
-	"Key pad is defined for Barrel as:\n"
-	"  8    Up\n"
-	"  ^\n"
-	"4< >6  Left, Right\n"
-	"  v\n"
-	"  2    Down\n"
-	"\n"
-	"Use the shift key and the up or down arrow keys to rotate "
-	"all the tiles.\n"
+"Press \"mouse-left\" button to move a tile. Release "
+"\"mouse-left\" button in the same row would move the tile towards\n"
+"the space (unless there is no space in that row).  "
+"Release on a different row will move the tiles up or down.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle.\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle orient mode.  Slightly "
+"more challenging on (default is off).\n"
+"\n"
+"Press \"I\" or \"i\" keys to toggle the pairs mode.  All "
+"the tiles rotate in pairs.  This is considerably\n"
+"more challenging on (default is on).\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Barrel as:\n"
+"  8    Up\n"
+"  ^\n"
+"4< >6  Left, Right\n"
+"  v\n"
+"  2    Down\n"
+"\n"
+"Use the shift key and the up or down arrow keys to rotate "
+"all the tiles.\n"
 };
 
 static const char referencesHelp[] = {
-	"L. E. Horden, Sliding Piece Puzzles (Recreations in "
-	"Mathematics Series), Oxford University\n"
-	"Press 1986, Plate X.\n"
-	"James G Nourse, The Simple Solutions to Cubic, Puzzles, "
-	"Bantam Books, New York, November 1981, pp 25-42.\n"
-	"John Ewing & Czes Kosniowski, Puzzle it Out: "
-	"Cubes Groups and Puzzles, Cambridge University Press,\n"
-	"New York, 1982, pp 50-54?\n"
+"L. E. Horden, Sliding Piece Puzzles (Recreations in "
+"Mathematics Series), Oxford University\n"
+"Press 1986, Plate X.\n"
+"James G Nourse, The Simple Solutions to Cubic, Puzzles, "
+"Bantam Books, New York, November 1981, pp 25-42.\n"
+"John Ewing & Czes Kosniowski, Puzzle it Out: "
+"Cubes Groups and Puzzles, Cambridge University Press,\n"
+"New York, 1982, pp 50-54?\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -447,7 +447,7 @@ HandleSolved(int counter, Boolean orient, Boolean pairs)
 	int k = (orient) ? 1 : 0, l = (pairs) ? 1 : 0;
 
 	if ((counter < barrelRecord[l][k].score ||
-			 barrelRecord[l][k].score <= NEVER)) {
+			barrelRecord[l][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		barrelRecord[l][k].score = counter;
 		(void) strncpy(barrelRecord[l][k].name, userNameDsp,
@@ -535,7 +535,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1100,8 +1106,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
