@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -88,105 +88,106 @@ static CubesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Cubes Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Cubes Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-block {color}] [-size{x|y|z} {int}] \n"
-	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
-	"\t[-[no]sound] [-bumpSound {filename}] [-dripSound {filename}]\n"
-	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-block {color}] [-{border|bd} {color}] [-[no]install]\n"
+"[-picture {filename}] [-delay msecs] [-[no]sound]\n"
+"[-bumpSound {filename}] [-dripSound {filename}]\n"
+"[-{font|fn} {fontname}] [-size{x|y|z} {int}] [-base {int}]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"A 3D  sliding block puzzle.  The cubes represented are  "
-	"flattened out on the plane.  If the Blocks Z slider is\n"
-	"greater than 1, then each group of boxes is a layer of the "
-	"puzzle.  If the Blocks Z slider = 1, then this is a\n"
-	"simple 15 tile puzzle.  The 15 puzzle was originally "
-	"made around 1879 (the 14-15  puzzle of Sam Loyd  was made\n"
-	"soon after.)  Similar 3D puzzles include  BloxBox; "
-	"Qrazy Qube (2x2x2) by P. Hein of Denmark and Varikon Box 'L\n"
-	"Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
-	"Toys & Games International USA.\n"
+"A 3D  sliding block puzzle.  The cubes represented are  "
+"flattened out on the plane.  If the Blocks Z slider is\n"
+"greater than 1, then each group of boxes is a layer of the "
+"puzzle.  If the Blocks Z slider = 1, then this is a\n"
+"simple 15 tile puzzle.  The 15 puzzle was originally "
+"made around 1879 (the 14-15  puzzle of Sam Loyd  was made\n"
+"soon after.)  Similar 3D puzzles include  BloxBox; "
+"Qrazy Qube (2x2x2) by P. Hein of Denmark and Varikon Box 'L\n"
+"Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
+"Toys & Games International USA.\n"
 };
 
 static const char featuresHelp[] = {
-	"Click \"mouse-left\" button to move a block.  Clicks on "
-	"a space, or clicks blocks that are not in line with\n"
-	"a space, will not move blocks.  Notice, one can move "
-	"more than  one block at a time  by clicking on\n"
-	"the block farthest from the space but still in line with "
-	"the space.  Since you only have a 2-D screen the\n"
-	"next level the down is either the box to the right of the "
-	"current box or the bottom of the current box.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle.\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to move a block in.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to move a block out.\n"
-	"\n"
-	"Press \"S\" or \"s\" keys to start the auto-solver.  Only "
-	"works on lxmx1 where l > 3 and m > 3.\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of blocks.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of blocks.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"the mouse.\n"
-	"Key pad is defined for Cubes as:\n"
-	"  /    Out\n"
-	"  8    Up\n"
-	"  ^\n"
-	"4<5>6  Left, In, Right\n"
-	"  v\n"
-	"  2    Down\n"
-	"\n"
-	"The control key allows you to change the complexity of "
-	"xcubes.  Hold down control key and use the keypad\n"
-	"or arrow keys to reduce or enlarge puzzle complexity.\n"
+"Click \"mouse-left\" button to move a block.  Clicks on "
+"a space, or clicks on blocks  that are not in line\n"
+"with a space, will not move the blocks.  Notice, one can move "
+"more than  one block at a time by clicking\n"
+"on the block farthest from the space but still in line "
+"with the space.  Since you only have a 2-D screen\n"
+"the next level the down is  either the box to the right of "
+"the current box  or the bottom of the current\n"
+"box.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle.\n"
+"\n"
+"Press \"I\" or \"i\" keys to move a block in.\n"
+"\n"
+"Press \"O\" or \"o\" keys to move a block out.\n"
+"\n"
+"Press \"S\" or \"s\" keys to start the auto-solver.  Only "
+"works on lxmx1 where l > 3 and m > 3.\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of blocks.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of blocks.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Cubes as:\n"
+"  /    Out\n"
+"  8    Up\n"
+"  ^\n"
+"4<5>6  Left, In, Right\n"
+"  v\n"
+"  2    Down\n"
+"\n"
+"The control key allows you to change the complexity of "
+"xcubes.  Hold down control key and use the keypad\n"
+"or arrow keys to reduce or enlarge puzzle complexity.\n"
 };
 
 static const char referencesHelp[] = {
-	"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
-	"Mathematics Series), Oxford University Press  1986,\n"
-	"pp 1, 157-159.\n"
-	"Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
-	"and Solve Them),  University of Washington\n"
-	"Press, Seattle 1987, p 126, 127.\n"
+"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
+"Mathematics Series), Oxford University Press  1986,\n"
+"pp 1, 157-159.\n"
+"Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
+"and Solve Them),  University of Washington\n"
+"Press, Seattle 1987, p 126, 127.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, only implemented for lxmx1 where "
-	"l > 3 and m > 3.\n"
+"Auto-solver: sorry, only implemented for lxmx1 where "
+"l > 3 and m > 3.\n"
 };
 
 #ifndef SCOREFILE
@@ -346,7 +347,7 @@ ReadRecords(void)
 			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
 				(void) fscanf(fp, "%d %s", &n, userName);
 				if (n <= cubesRecord[i][j][k].score ||
-				    cubesRecord[i][j][k].score <= NEVER) {
+					  cubesRecord[i][j][k].score <= NEVER) {
 					cubesRecord[k][j][i].score = cubesRecord[k][i][j].score =
 						cubesRecord[j][k][i].score = cubesRecord[j][i][k].score =
 						cubesRecord[i][k][j].score = cubesRecord[i][j][k].score = n;
@@ -569,7 +570,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -988,15 +995,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1063,8 +1070,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
