@@ -923,6 +923,9 @@ GetPieces(DinoWidget w)
 	(void) fscanf(fp, "%d", &moves);
 	ScanStartPosition(fp, w);
 	SetDino(w, DINO_RESTORE);
+#ifdef WINVER
+	SetStartPosition(w);
+#endif
 	ScanMoves(fp, w, moves);
 	(void) fclose(fp);
 	(void) printf("%s: mode %d, orient %d, practice %d, moves %d.\n",
@@ -1009,6 +1012,9 @@ UndoPieces(DinoWidget w)
 			MovePieces(w, face, position, direction, style);
 			SetDinoMove(w, DINO_UNDO, face, position, direction,
 				style);
+			if (CheckSolved(w)) {
+				SetDino(w, DINO_SOLVED);
+			}
 		}
 	}
 }
