@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -148,12 +148,18 @@ static XtActionsRec actionsListDino3D[] =
 
 static XtResource resourcesDino3D[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(DinoWidget, dino.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(DinoWidget, dino.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(DinoWidget, core.width),
+	 XtRString, (caddr_t) "250"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(DinoWidget, core.height),
+	 XtRString, (caddr_t) "400"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -163,9 +169,6 @@ static XtResource resourcesDino3D[] =
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
-	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(DinoWidget, dino.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.faceName[0]),
 	 XtRString, (caddr_t) "Red"},
@@ -184,23 +187,41 @@ static XtResource resourcesDino3D[] =
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.faceName[5]),
 	 XtRString, (caddr_t) "Orange"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(DinoWidget, core.width),
-	 XtRString, (caddr_t) "250"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(DinoWidget, core.height),
-	 XtRString, (caddr_t) "400"},
+	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(DinoWidget, dino.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
+	{XtNfont, XtCFont, XtRString, sizeof (String),
+	 XtOffset(DinoWidget, dino.font),
+	 XtRString, (caddr_t) "9x15bold"},
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.mode),
 	 XtRString, (caddr_t) "3"},	/*DEFAULTMODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.orient),
 	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.mono),
+	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.practice),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(DinoWidget, dino.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(DinoWidget, dino.scoreFile),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.reverse),
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
+	 XtOffset(DinoWidget, dino.menu),
+	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.cheat),
 	 XtRString, (caddr_t) "FALSE"},
 	{XtNface, XtCFace, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.currentFace),
@@ -214,27 +235,6 @@ static XtResource resourcesDino3D[] =
 	{XtNstyle, XtCStyle, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.style),
 	 XtRString, (caddr_t) "-1"},
-	{XtNpractice, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.practice),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNfont, XtCFont, XtRString, sizeof (String),
-	 XtOffset(DinoWidget, dino.font),
-	 XtRString, (caddr_t) "9x15bold"},
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.cheat),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.scoreOnly),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(DinoWidget, dino.versionOnly),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
-	 XtOffset(DinoWidget, dino.menu),
-	 XtRString, (caddr_t) "-1"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(DinoWidget, dino.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -460,7 +460,7 @@ void
 DrawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 {
 	GC          faceGC, borderGC;
-	int         corner, dx, dy, letterX, letterY;
+	int         corner = 0, dx, dy, letterX, letterY;
 
 	MapTo3D(w, face, position, &corner);
 	CubeOffset3D(w, face, corner, &dx, &dy);
