@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -88,117 +88,116 @@ static DinoRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Dino Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Dino Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
-	"\t[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
-	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-face{0|1|2|3|4|5} {color}] [-{border|bd} {color}]\n"
+"[-{font|fn} {fontname}] [-{mode {int} | both}]\n"
+"[-[no]orient] [-[no]practice] [-userName {string}]\n"
+"[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The period 2 turning (i.e. the edges turn with 180 "
-	"degree intervals) was suggested by Derek Bosch\n"
-	"<bosch@sgi.com>.  The physical puzzle has period 3 "
-	"turning (i.e. the points turn with 120 degree\n"
-	"intervals) is called a Triangle - 4 Cube - Dinosaur "
-	"with colored dinosaurs on it, (or Triangle - 4 Cube -\n"
-	"6 Colors with solid colors, (a 4 color and a 2 color "
-	"are also available with point oriented coloring))\n"
-	"manufactured by The International Puzzle & Games "
-	"(Great Animation International Corporation).\n"
+"The period 2 turning (i.e. the edges turn with 180 "
+"degree intervals) was suggested by Derek Bosch\n"
+"<bosch@sgi.com>.  The physical puzzle has period 3 "
+"turning (i.e. the points turn with 120 degree\n"
+"intervals) is called a Triangle - 4 Cube - Dinosaur "
+"with colored dinosaurs on it, (or Triangle - 4 Cube -\n"
+"6 Colors with solid colors, (a 4 color and a 2 color "
+"are also available with point oriented coloring))\n"
+"manufactured by The International Puzzle & Games "
+"(Great Animation International Corporation).\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece on the same face.\n"
-	"The pieces will then turn towards where the mouse "
-	"button was released.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
-	"has to orient the faces in orient mode, besides\n"
-	"getting all the faces to be the same color.  To do this "
-	"one has to get the lines to be oriented in\n"
-	"the same direction.  This does add complexity (ever so "
-	"slightly, there are only 2 possibilities) so there\n"
-	"are 2 sets of records.\n"
-	"\n"
-	"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad "
-	"2, 3) to change modes to Period 2, Period 3, or Both.\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"clicks.\n"
-	"Key pad is defined for Dino2d as:\n"
-	"7 8 9  Upper Left, Up, Upper Right\n"
-	"  ^\n"
-	"4< >6  Left, Right\n"
-	"  v\n"
-	"1 2 3  Lower Left, Down, Lower Right\n"
-	"Note: Up, Left, Right, and Down only work when the "
-	"control key is pressed and there is no analog for\n"
-	"Dino3d.\n"
-	"Key pad for Dino3d, use must use your intuition (is this "
-	"a cop out or what?).  The key pad is defined\n"
-	"differently depending on which side of the cube your mouse "
-	"is pointing at.\n"
-	"\n"
-	"Use the alt key and the left mouse button, keypad, or arrow "
-	"keys to move the center of the cube.  The 2 opposite\n"
-	"corners do not move.\n"
-	"\n"
-	"Use the shift keys and the left mouse button, keypad, "
-	"or arrow key to access \"Period 2\" turns from \"Both\" mode,\n"
-	"otherwise it assumes \"Period 3\" turning.  Edges turn in "
-	"\"Period 2\" and corners turn in \"Period 3\".  The\n"
-	"\"Period 2\" mode has extra cuts around the faces.\n"
-	"\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys to move the whole cube.  This is\n"
-	"not recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece on the same face.\n"
+"The pieces will then turn towards where the mouse "
+"button was released.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
+"has to orient the faces in orient mode, besides\n"
+"getting all the faces to be the same color.  To do this "
+"one has to get the lines to be oriented in\n"
+"the same direction.  This does add complexity (ever so "
+"slightly, there are only 2 possibilities) so there\n"
+"are 2 sets of records.\n"
+"\n"
+"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad "
+"2, 3) to change modes to Period 2, Period 3, or Both.\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Dino2d as:\n"
+"7 8 9  Upper Left, Up, Upper Right\n"
+"  ^\n"
+"4< >6  Left, Right\n"
+"  v\n"
+"1 2 3  Lower Left, Down, Lower Right\n"
+"Note: Up, Left, Right, and Down only work when the "
+"control key is pressed and there is no analog for\n"
+"Dino3d.\n"
+"Key pad for Dino3d, use must use your intuition (is this "
+"a cop out or what?).  The key pad is defined\n"
+"differently depending on which side of the cube your mouse "
+"is pointing at.\n"
+"\n"
+"Use the alt key and the left mouse button, keypad, or arrow "
+"keys to move the center of the cube.  The 2 opposite\n"
+"corners do not move.\n"
+"\n"
+"Use the shift keys and the left mouse button, keypad, "
+"or arrow key to access \"Period 2\" turns from \"Both\" mode,\n"
+"otherwise it assumes \"Period 3\" turning.  Edges turn in "
+"\"Period 2\" and corners turn in \"Period 3\".  The\n"
+"\"Period 2\" mode has extra cuts around the faces.\n"
+"\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys to move the whole cube.  This is\n"
+"not recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"International Puzzles & Games Catalog.\n"
+"International Puzzles & Games Catalog.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -589,7 +588,13 @@ void
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1196,15 +1201,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1266,8 +1271,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
