@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -193,12 +193,18 @@ static XtActionsRec actionsListHexagons[] =
 
 static XtResource resourcesHexagons[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(HexagonsWidget, hexagons.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(HexagonsWidget, hexagons.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(HexagonsWidget, core.width),
+	 XtRString, (caddr_t) "259"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(HexagonsWidget, core.height),
+	 XtRString, (caddr_t) "200"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(HexagonsWidget, hexagons.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -214,27 +220,6 @@ static XtResource resourcesHexagons[] =
 	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(HexagonsWidget, hexagons.borderColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(HexagonsWidget, core.width),
-	 XtRString, (caddr_t) "259"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(HexagonsWidget, core.height),
-	 XtRString, (caddr_t) "200"},
-	{XtNsizeX, XtCSizeX, XtRInt, sizeof (int),
-	 XtOffset(HexagonsWidget, hexagons.sizeX),
-	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESX */
-	{XtNsizeY, XtCSizeY, XtRInt, sizeof (int),
-	 XtOffset(HexagonsWidget, hexagons.sizeY),
-	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESY */
-	{XtNcorners, XtCCorners, XtRBoolean, sizeof (Boolean),
-	 XtOffset(HexagonsWidget, hexagons.corners),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTCORNERS */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(HexagonsWidget, hexagons.mono),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(HexagonsWidget, hexagons.reverse),
-	 XtRString, (caddr_t) "FALSE"},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.install),
 	 XtRString, (caddr_t) "FALSE"},
@@ -253,21 +238,36 @@ static XtResource resourcesHexagons[] =
 	{XtNfont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(HexagonsWidget, hexagons.font),
 	 XtRString, (caddr_t) "9x15bold"},
+	{XtNsizeX, XtCSizeX, XtRInt, sizeof (int),
+	 XtOffset(HexagonsWidget, hexagons.sizeX),
+	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESX */
+	{XtNsizeY, XtCSizeY, XtRInt, sizeof (int),
+	 XtOffset(HexagonsWidget, hexagons.sizeY),
+	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESY */
+	{XtNcorners, XtCCorners, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.corners),
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTCORNERS */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.base),
 	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(HexagonsWidget, hexagons.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(HexagonsWidget, hexagons.cheat),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(HexagonsWidget, hexagons.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(HexagonsWidget, hexagons.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
 	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.versionOnly),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.cheat),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -653,7 +653,7 @@ bresenhamLine(int startX, int startY, int endX, int endY,
 			*pixY += dy;
 			pix++;
 			if (*pixY == endY)
-				return True; 
+				return True;
 		}
 		return False;
 	}
@@ -952,55 +952,57 @@ FindMovableTile(HexagonsWidget w, int pos, int posRow, int spaceType, int side,
 	int *tilePos, int *tileRow)
 {
 	switch (spaceType) {
-		case TRBL:
-			if (side == HIGH) {
-				*tileRow = posRow;
-				*tilePos = pos + 1;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 1;
-			}
-			break;
-		case TLBR:
-			if (side == HIGH) {
-				*tileRow = posRow;
-				*tilePos = pos - 1;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow + 1 :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 2;
-			}
-			break;
-		case ROW:
-			if (side == HIGH) {
-				*tileRow = posRow + 1;
-				*tilePos = (posRow < w->hexagons.sizeY - 1) ?
-					pos + w->hexagons.sizeX + posRow :
-					pos + 2 * w->hexagons.sizeY +
-					w->hexagons.sizeX - posRow - 3;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 1;
-			}
-			break;
-		default:
-			{
-				char *buf;
+	case TRBL:
+		if (side == HIGH) {
+			*tileRow = posRow;
+			*tilePos = pos + 1;
+		} else {	/* side == LOW */
+			*tileRow = posRow - 1;
+			*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+				pos - w->hexagons.sizeX - posRow :
+				pos - 2 * w->hexagons.sizeY -
+				w->hexagons.sizeX + posRow + 1;
+		}
+		break;
+	case TLBR:
+		if (side == HIGH) {
+			*tileRow = posRow;
+			*tilePos = pos - 1;
+		} else {	/* side == LOW */
+			*tileRow = posRow - 1;
+			*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+				pos - w->hexagons.sizeX - posRow + 1 :
+				pos - 2 * w->hexagons.sizeY -
+				w->hexagons.sizeX + posRow + 2;
+		}
+		break;
+	case ROW:
+		if (side == HIGH) {
+			*tileRow = posRow + 1;
+			*tilePos = (posRow < w->hexagons.sizeY - 1) ?
+				pos + w->hexagons.sizeX + posRow :
+				pos + 2 * w->hexagons.sizeY +
+				w->hexagons.sizeX - posRow - 3;
+		} else {	/* side == LOW */
+			*tileRow = posRow - 1;
+			*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+				pos - w->hexagons.sizeX - posRow :
+				pos - 2 * w->hexagons.sizeY -
+				w->hexagons.sizeX + posRow + 1;
+		}
+		break;
+	default:
+		{
+			char *buf;
 
-				intCat(&buf,
-					"FindMovableTile: spaceType \n",
-					spaceType);
-				DISPLAY_WARNING(buf);
-				free(buf);
-			}
+			intCat(&buf,
+				"FindMovableTile: spaceType \n",
+				spaceType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+			*tileRow = 0;
+			*tilePos = 0;
+		}
 	}
 }
 
@@ -1063,54 +1065,65 @@ MovableCornerTiles(HexagonsWidget w, int direction,
 		w->hexagons.spacePosition[HIGH], w->hexagons.spacePosition[LOW],
 		w->hexagons.spaceRow[HIGH], w->hexagons.spaceRow[LOW]);
 	switch (spaceType) {
-		case TRBL:
-			if (direction == TR || direction == BL)
+	case TRBL:
+		if (direction == TR || direction == BL)
+			return FALSE;
+		side = NextToWall(w, w->hexagons.spacePosition[highest],
+			w->hexagons.spaceRow[highest], spaceType);
+		if (side != -1) {
+			if ((side == HIGH && direction == RIGHT) ||
+			    (side == HIGH && direction == BR) ||
+			    (side == LOW && direction == LEFT) ||
+			    (side == LOW && direction == TL))
 				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == HIGH && direction == RIGHT) ||
-				    (side == HIGH && direction == BR) ||
-				    (side == LOW && direction == LEFT) ||
-				    (side == LOW && direction == TL))
-					return FALSE;
-			} else
-				side = (direction == TL || direction == LEFT);
-			*space = (direction == BR || direction == LEFT);
-			break;
-		case TLBR:
-			if (direction == TL || direction == BR)
+		} else
+			side = (direction == TL || direction == LEFT);
+		*space = (direction == BR || direction == LEFT);
+		break;
+	case TLBR:
+		if (direction == TL || direction == BR)
+			return FALSE;
+		side = NextToWall(w, w->hexagons.spacePosition[highest],
+			w->hexagons.spaceRow[highest], spaceType);
+		if (side != -1) {
+			if ((side == LOW && direction == TR) ||
+			    (side == LOW && direction == RIGHT) ||
+			    (side == HIGH && direction == BL) ||
+			    (side == HIGH && direction == LEFT))
 				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == LOW && direction == TR) ||
-				    (side == LOW && direction == RIGHT) ||
-				    (side == HIGH && direction == BL) ||
-				    (side == HIGH && direction == LEFT))
-					return FALSE;
-			} else
-				side = (direction == TR || direction == RIGHT);
-			*space = (direction == RIGHT || direction == BL);
-			break;
-		case ROW:
-			if (direction == LEFT || direction == RIGHT)
+		} else
+			side = (direction == TR || direction == RIGHT);
+		*space = (direction == RIGHT || direction == BL);
+		break;
+	case ROW:
+		if (direction == LEFT || direction == RIGHT)
+			return FALSE;
+		side = NextToWall(w, w->hexagons.spacePosition[highest],
+			   w->hexagons.spaceRow[highest], spaceType);
+		if (side != -1) {
+			if ((side == LOW && direction == TR) ||
+			    (side == HIGH && direction == BR) ||
+			    (side == HIGH && direction == BL) ||
+			    (side == LOW && direction == TL))
 				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				   w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == LOW && direction == TR) ||
-				    (side == HIGH && direction == BR) ||
-				    (side == HIGH && direction == BL) ||
-				    (side == LOW && direction == TL))
-					return FALSE;
-			} else
-				side = (direction == TR || direction == TL);
-			*space = (direction == TR || direction == BR);
-			break;
+		} else
+			side = (direction == TR || direction == TL);
+		*space = (direction == TR || direction == BR);
+		break;
+	default:
+		{
+			char * buf;
+
+			intCat(&buf, "MovableCornerTiles: spaceType ",
+				spaceType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+			*space = 0;
+		}
 	}
 	FindMovableTile(w, w->hexagons.spacePosition[highest],
-	  w->hexagons.spaceRow[highest], spaceType, side, position, posRow);
+		w->hexagons.spaceRow[highest], spaceType, side, position,
+		posRow);
 	return TRUE;
 }
 
@@ -1529,7 +1542,7 @@ MoveNoCornTiles(HexagonsWidget w, int from, int posRow, int fast)
 {
 #ifdef ANIMATE
 	if (fast != INSTANT && w->hexagons.delay > 0) {
-		w->hexagons.currentPosition = from; 
+		w->hexagons.currentPosition = from;
 		w->hexagons.currentRow[ROW] = Row(w, from);
 		w->hexagons.currentRow[TRBL] =
 			TrBl(w, from, w->hexagons.currentRow[ROW]);
@@ -3166,7 +3179,7 @@ SpeedHexagons(HexagonsWidget w
 )
 {
 	SpeedTiles(w);
-} 
+}
 
 #ifndef WINVER
 static
@@ -3179,7 +3192,7 @@ SlowHexagons(HexagonsWidget w
 )
 {
 	SlowTiles(w);
-} 
+}
 
 #ifndef WINVER
 static
