@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -89,105 +89,104 @@ static HexagonsRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Hexagons Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Hexagons Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-tile {color}] [-size{x|y} {int}]\n"
-	"\t[-[no]corners] [-[no]install] [-picture {filename}]\n"
-	"\t[-delay msecs] [-[no]sound] [-bumpSound {filename}]\n"
-	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-{border|bd} {color}] [-delay msecs]\n"
+"[-[no]sound] [-bumpSound {filename}]\n"
+"[-{font|fn} {fontname}] [-size{x|y} {int}] [-[no]corners]\n"
+"[-base {int}] [-userName {string}] [-scoreFile {filename}]\n"
+"[-scores] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"A sliding tile puzzle.  A hexagonal version of the "
-	"15 puzzle.  The 17 puzzle was conceived of by Alwin Vietor\n"
-	"and marketed in 1885 in Germany as \"Trilemma\" with "
-	"round pieces.  Sam Cornwell rediscovered this in 1989\n"
-	"with \"Clockblocks\" of which 12 were numbered using "
-	"hexagonal pieces.  Also he produced a smaller 12 block\n"
-	"puzzle with 9 that were numbered called \"Ninefield\".  Also "
-	"Bernhard Wiezorke came up with the similar 17 \n"
-	"puzzle, \"Hexafax, the New Fifteen Puzzle\", in 1991 and a "
-	"smaller 11 piece \"Counterfax\" of which 8 were\n"
-	"numbered.\n"
+"A sliding tile puzzle.  A hexagonal version of the "
+"15 puzzle.  The 17 puzzle was conceived of by Alwin Vietor\n"
+"and marketed in 1885 in Germany as \"Trilemma\" with "
+"round pieces.  Sam Cornwell rediscovered this in 1989\n"
+"with \"Clockblocks\" of which 12 were numbered using "
+"hexagonal pieces.  Also he produced a smaller 12 block\n"
+"puzzle with 9 that were numbered called \"Ninefield\".  Also "
+"Bernhard Wiezorke came up with the similar 17 \n"
+"puzzle, \"Hexafax, the New Fifteen Puzzle\", in 1991 and a "
+"smaller 11 piece \"Counterfax\" of which 8 were\n"
+"numbered.\n"
 };
 
 static const char featuresHelp[] = {
-	"If in corners mode: Press \"mouse-left\" button to move "
-	"a tile, then release \"mouse-left\" button on a space.\n"
-	"It will not move if blocked.  One can only move one "
-	"tile at a time. The only tiles that can be moved are\n"
-	"the tile(s) next to both spaces.\n"
-	"If in nocorners mode: Click \"mouse-left\" button to "
-	"move a tile.  One can move more than one tile at a time\n"
-	"and one is not constrained by parity.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle corners mode.  "
-	"(Default is on).\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"the mouse.\n"
-	"Key pad is defined for Hexagons as:\n"
-	"7   9  Upper Left, Upper Right\n"
-	"  ^\n"
-	"4< >6  Left, Right\n"
-	"  v\n"
-	"1   3  Bottom Left, Bottom Right\n"
-	"\n"
-	"The control key allows you to change the complexity of "
-	"xhexagons.  Hold down control key and use the keypad\n"
-	"or arrow keys to reduce or enlarge puzzle complexity.\n"
+"If in corners mode: Press \"mouse-left\" button to move "
+"a tile, then release \"mouse-left\" button on a space.\n"
+"It will not move if blocked.  One can only move one "
+"tile at a time. The only tiles that can be moved are\n"
+"the tile(s) next to both spaces.\n"
+"If in nocorners mode: Click \"mouse-left\" button to "
+"move a tile.  One can move more than one tile at a time\n"
+"and one is not constrained by parity.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle.\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle corners mode.  "
+"(Default is on).\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Hexagons as:\n"
+"7   9  Upper Left, Upper Right\n"
+"  ^\n"
+"4< >6  Left, Right\n"
+"  v\n"
+"1   3  Bottom Left, Bottom Right\n"
+"\n"
+"The control key allows you to change the complexity of "
+"xhexagons.  Hold down control key and use the keypad\n"
+"or arrow keys to reduce or enlarge puzzle complexity.\n"
 };
 
 static const char referencesHelp[] = {
-	"Dieter Gebhardt, \"From Trilemma to Counterfax\", CFF 53, "
-	"October 2000, pp 8-10.\n"
-	"Sam Cornwell, \"Ninefield: a Sliding Block Puzzle\", "
-	"CFF 57, March 2002, pp 4-5.\n"
-	"Dieter Gebhardt, \"Ninefield Revisited\", CFF 58, "
-	"July 2002, p 21.\n"
-	"Bernhard Wiezorke, \"Hexafax, the New Fifteen Puzzle\" "
-	"brochure.\n"
+"Dieter Gebhardt, \"From Trilemma to Counterfax\", CFF 53, "
+"October 2000, pp 8-10.\n"
+"Sam Cornwell, \"Ninefield: a Sliding Block Puzzle\", "
+"CFF 57, March 2002, pp 4-5.\n"
+"Dieter Gebhardt, \"Ninefield Revisited\", CFF 58, "
+"July 2002, p 21.\n"
+"Bernhard Wiezorke, \"Hexafax, the New Fifteen Puzzle\" "
+"brochure.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -337,10 +336,10 @@ ReadRecords(void)
 		  for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
 		    (void) fscanf(fp, "%d %s\n", &n, userName);
 		    if (n <= hexagonsRecord[i][j][k].score ||
-		    		hexagonsRecord[i][j][k].score <= NEVER) {
+		        hexagonsRecord[i][j][k].score <= NEVER) {
 		      hexagonsRecord[i][j][k].score = n;
 		      (void) strncpy(hexagonsRecord[i][j][k].name,
-		      		userName, USERNAMELEN);
+		        userName, USERNAMELEN);
 		    }
 		}
 	(void) fclose(fp);
@@ -534,7 +533,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -557,7 +562,7 @@ SetHexagons(HexagonsWidget w, int reason)
 #else
 static void
 CallbackHexagons(Widget w, caddr_t clientData,
-		 hexagonsCallbackStruct * callData)
+		hexagonsCallbackStruct * callData)
 #endif
 {
 #ifndef WINVER
@@ -941,15 +946,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1012,8 +1017,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
