@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -247,12 +247,18 @@ static XtActionsRec actionsListMball[] =
 
 static XtResource resourcesMball[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(MballWidget, core.width),
+	 XtRString, (caddr_t) "200"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(MballWidget, core.height),
+	 XtRString, (caddr_t) "400"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MballWidget, mball.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -262,9 +268,6 @@ static XtResource resourcesMball[] =
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(MballWidget, mball.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
-	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(MballWidget, mball.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNwedgeColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(MballWidget, mball.wedgeName[0]),
 	 XtRString, (caddr_t) "yellow"},
@@ -301,18 +304,12 @@ static XtResource resourcesMball[] =
 	{XtNwedgeColor11, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(MballWidget, mball.wedgeName[11]),
 	 XtRString, (caddr_t) "IndianRed"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(MballWidget, core.width),
-	 XtRString, (caddr_t) "200"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(MballWidget, core.height),
-	 XtRString, (caddr_t) "400"},
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.mono),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.reverse),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(MballWidget, mball.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
+	{XtNfont, XtCFont, XtRString, sizeof (String),
+	 XtOffset(MballWidget, mball.font),
+	 XtRString, (caddr_t) "9x15bold"},
 	{XtNwedges, XtCWedges, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.wedges),
 	 XtRString, (caddr_t) "8"}, /* DEFAULTWEDGES */
@@ -325,18 +322,15 @@ static XtResource resourcesMball[] =
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.practice),
 	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNfont, XtCFont, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.font),
-	 XtRString, (caddr_t) "9x15bold"},
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.base),
 	 XtRString, (caddr_t) "16"}, /* DEFAULTBASE */
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.cheat),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(MballWidget, mball.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(MballWidget, mball.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
@@ -346,6 +340,12 @@ static XtResource resourcesMball[] =
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.menu),
 	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.cheat),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(MballWidget, mball.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -1442,7 +1442,7 @@ MovePieces(MballWidget w, int wedge, int ring, int direction)
 
 	if (direction == CW || direction == CCW) {	/* rotate ring */
 		int newI;
-		MballLoc temp1, temp2;
+		MballLoc temp1 = {0, 0}, temp2;
 
 		for (i = 0; i < w->mball.wedges; i++) {
 			newI = (direction == CW) ? i : w->mball.wedges - 1 - i;
@@ -1821,6 +1821,9 @@ UndoWedges(MballWidget w)
 		else {
 			MovePieces(w, wedge, ring, direction);
 			SetMball(w, MBALL_UNDO);
+			if (CheckSolved(w)) {
+				SetMball(w, MBALL_SOLVED);
+			}
 		}
 	}
 }
