@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -87,113 +87,113 @@ static MballRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Mball Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Mball Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
-	"\t[-wedges {int}] [-ring {int}] [-[no]orient] [-[no]practice]\n"
-	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
+"[-{border|bd} {color}] [-{font|fn} {fontname}]\n"
+"[-wedges {int}] [-ring {int}] [-[no]orient]\n"
+"[-[no]practice] [-base {int}] [-userName {string}]\n"
+"[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original puzzle has 8 sectors on a sphere "
-	"(longitudinal cuts), with each sector divided into 4 segments\n"
-	"(latitudinal cuts).  There are essentially 3 varieties: "
-	"Geomaster 8 colors (beachball, default colors in this\n"
-	"puzzle), Duomaster 2 colors (black and white beachball), "
-	"and a variety of picture Masterballs.  For some reason,\n"
-	"they say the Geomaster is easier than the Duomaster.  The "
-	"picture Masterballs are the hardest since all the pieces\n"
-	"have a set solved position.  On the Duo and Geo Masterballs "
-	"pieces could be swapped or in a different order and still\n"
-	"be in a solved position.  Zurick University's Mathematics "
-	"faculty has calculated that Masterball's 32 segments can\n"
-	"be arranged in 355,682,548,566,633,480,192,000,000 different "
-	"possible combinations.  Masterball was invented by Dr.\n"
-	"Geza Gyovai Hungarian Engineer, manufactured by Whole "
-	"Systems Design, Inc..\n"
+"The original puzzle has 8 sectors on a sphere "
+"(longitudinal cuts), with each sector divided into 4 segments\n"
+"(latitudinal cuts).  There are essentially 3 varieties: "
+"Geomaster 8 colors (beachball, default colors in this\n"
+"puzzle), Duomaster 2 colors (black and white beachball), "
+"and a variety of picture Masterballs.  For some reason,\n"
+"they say the Geomaster is easier than the Duomaster.  The "
+"picture Masterballs are the hardest since all the pieces\n"
+"have a set solved position.  On the Duo and Geo Masterballs "
+"pieces could be swapped or in a different order and still\n"
+"be in a solved position.  Zurick University's Mathematics "
+"faculty has calculated that Masterball's 32 segments can\n"
+"be arranged in 355,682,548,566,633,480,192,000,000 different "
+"possible combinations.  Masterball was invented by Dr.\n"
+"Geza Gyovai Hungarian Engineer, manufactured by Whole "
+"Systems Design, Inc..\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece and the pieces will\n"
-	"then turn towards where the mouse button was released.  "
-	"Usually, a click and release on the same wedge is\n"
-	"ambiguous and the puzzle will not turn.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of rings.\n"
-	"\n"
-	"Press \"D\" or \"d\" keys to decrease the number of rings.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
-	"has to orient the wedges in orient mode, besides\n"
-	"getting all the wedges to be the same color.  To do this "
-	"one has to get the numbers to be on the same side\n"
-	"of the ball in clockwise order.\n"
-	"\n"
-	"Press \"2\", \"4\", \"6\", \"8\", \"0\", or \"=\" keys "
-	"(not the keypad 2, 4, 6, 8, 0) to change to 2, 4, 6, 8, 10,\n"
-	"or 12 wedges, respectively.  Note: if there were odd "
-	"number of wedges, there would be no 180 degree turn and\n"
-	"therefore the puzzle would be inoperable.\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"mouse clicks.\n"
-	"Key pad is defined for Master Ball as:\n"
-	"N / *  Upper Upper Left, Counterclockwise, Upper Upper Right\n"
-	"7 8 9  Up, Upper Right\n"
-	"  ^\n"
-	"4<5>6  Left, Clockwise, Right\n"
-	"  v\n"
-	"1 2 3  Lower Left, Down, Lower Right\n"
-	" 0  .  Lower Lower Left, Lower Lower Right\n"
-	"\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys to move the whole Masterball.  This is not\n"
-	"recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece and the pieces will\n"
+"then turn towards where the mouse button was released.  "
+"Usually, a click and release on the same wedge is\n"
+"ambiguous and the puzzle will not turn.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of rings.\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of rings.\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
+"has to orient the wedges in orient mode, besides\n"
+"getting all the wedges to be the same color.  To do this "
+"one has to get the numbers to be on the same side\n"
+"of the ball in clockwise order.\n"
+"\n"
+"Press \"2\", \"4\", \"6\", \"8\", \"0\", or \"=\" keys "
+"(not the keypad 2, 4, 6, 8, 0) to change to 2, 4, 6, 8, 10,\n"
+"or 12 wedges, respectively.  Note: if there were odd "
+"number of wedges, there would be no 180 degree turn and\n"
+"therefore the puzzle would be inoperable.\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Master Ball as:\n"
+"N / *  Upper Upper Left, Counterclockwise, Upper Upper Right\n"
+"7 8 9  Up, Upper Right\n"
+"  ^\n"
+"4<5>6  Left, Clockwise, Right\n"
+"  v\n"
+"1 2 3  Lower Left, Down, Lower Right\n"
+" 0  .  Lower Lower Left, Lower Lower Right\n"
+"\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys to move the whole Masterball.  This is not\n"
+"recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"http://wsd.com/masterball\n"
+"http://wsd.com/masterball\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -544,7 +544,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOBODY) ||
@@ -766,7 +772,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			XtVaSetValues(w, XtNwedges, wedges, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(wedge[(wedges - MINWEDGES) / 2],
-				 True, True);
+				True, True);
 #endif
 #endif
 			break;
@@ -1020,15 +1026,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1091,8 +1097,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
