@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -211,24 +211,27 @@ static XtActionsRec actionsListMlink[] =
 
 static XtResource resourcesMlink[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(MlinkWidget, mlink.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(MlinkWidget, mlink.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(MlinkWidget, core.width),
+	 XtRString, (caddr_t) "512"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(MlinkWidget, core.height),
+	 XtRString, (caddr_t) "512"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MlinkWidget, mlink.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MlinkWidget, mlink.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(MlinkWidget, mlink.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
-	{XtNtileBorder, XtCForeground, XtRPixel, sizeof (Pixel),
-	 XtOffset(MlinkWidget, mlink.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
 	{XtNtileColor, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MlinkWidget, mlink.tileColor),
 	 XtRString, (caddr_t) "black" /*XtDefaultForeground*/},
@@ -256,33 +259,9 @@ static XtResource resourcesMlink[] =
 	{XtNfaceColor7, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(MlinkWidget, mlink.faceName[7]),
 	 XtRString, (caddr_t) "orange"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(MlinkWidget, core.width),
-	 XtRString, (caddr_t) "512"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(MlinkWidget, core.height),
-	 XtRString, (caddr_t) "512"},
-	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
-	 XtOffset(MlinkWidget, mlink.tiles),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTTILES */
-	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
-	 XtOffset(MlinkWidget, mlink.faces),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTFACES */
-	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.orient),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
-	{XtNmiddle, XtCMiddle, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.middle),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTMIDDLE */
-	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.practice),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.mono),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.reverse),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNtileBorder, XtCForeground, XtRPixel, sizeof (Pixel),
+	 XtOffset(MlinkWidget, mlink.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.install),
 	 XtRString, (caddr_t) "FALSE"},
@@ -304,15 +283,30 @@ static XtResource resourcesMlink[] =
 	{XtNfont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(MlinkWidget, mlink.font),
 	 XtRString, (caddr_t) "9x15bold"},
+	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
+	 XtOffset(MlinkWidget, mlink.tiles),
+	 XtRString, (caddr_t) "4"}, /* DEFAULTTILES */
+	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
+	 XtOffset(MlinkWidget, mlink.faces),
+	 XtRString, (caddr_t) "4"}, /* DEFAULTFACES */
+	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.orient),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
+	{XtNmiddle, XtCMiddle, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.middle),
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTMIDDLE */
+	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.practice),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.base),
 	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MlinkWidget, mlink.cheat),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(MlinkWidget, mlink.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(MlinkWidget, mlink.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
@@ -322,6 +316,12 @@ static XtResource resourcesMlink[] =
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.menu),
 	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.cheat),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(MlinkWidget, mlink.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -1163,7 +1163,6 @@ MoveTiles(MlinkWidget w, int from, int fast)
 	int i =	w->mlink.currentTile = Column(w, from);
 	int j = w->mlink.currentFace = Row(w, from);
 	int l = i + w->mlink.tiles * j - w->mlink.spacePosition;
-	int pos, posNext, aTile, dir;
 
 	w->mlink.currentRef = from;
 	if (l / w->mlink.tiles == 0 &&
@@ -1176,6 +1175,8 @@ MoveTiles(MlinkWidget w, int from, int fast)
 				AnimateSlide(w, l, LEFT, fast, False);
 			}
 		} else {
+			int pos, posNext, aTile, dir;
+
 			dir = (l < 0) ? RIGHT : LEFT;
 			if (l < 0)
 				l = -l;
@@ -1189,7 +1190,8 @@ MoveTiles(MlinkWidget w, int from, int fast)
 			}
 			w->mlink.spacePosition = from;
 			w->mlink.tileOfPosition[from] = 0;
-			DrawTile(w, w->mlink.spacePosition, True, True, FALSE, 0, 0);
+			DrawTile(w, w->mlink.spacePosition, True, True,
+				FALSE, 0, 0);
 		}
 	}
 	w->mlink.currentRef = -w->mlink.tileFaces;
@@ -1213,8 +1215,8 @@ RotateTiles(MlinkWidget w, int start, int finish, int direction, int fast)
 	for (i = start; i <= finish; i++) {
 		currTile = w->mlink.tileOfPosition[r * w->mlink.tiles + i];
 		for (k = 1; k <= w->mlink.faces; k++) {
-			newR = (direction == TOP) ? (r +
-				w->mlink.faces - 1) % w->mlink.faces :
+			newR = (direction == TOP) ?
+				(r + w->mlink.faces - 1) % w->mlink.faces :
 				(r + 1) % w->mlink.faces;
 			pos = r * w->mlink.tiles + i;
 			newPos = newR * w->mlink.tiles + i;
@@ -1254,7 +1256,7 @@ RotateTiles(MlinkWidget w, int start, int finish, int direction, int fast)
 	}
 #endif
 }
- 
+
 static Boolean
 MoveTilesDir(MlinkWidget w, int direction, int tile, Boolean all, int fast)
 {
@@ -1274,8 +1276,8 @@ MoveTilesDir(MlinkWidget w, int direction, int tile, Boolean all, int fast)
 		RotateTiles(w, start, finish, TOP, fast);
 		return True;
 	case RIGHT:
-		if (tile >= 0 && Row(w, w->mlink.spacePosition) == Row(w, tile))
- {
+		if (tile >= 0 && Row(w, w->mlink.spacePosition) ==
+				Row(w, tile)) {
 			MoveTiles(w, tile, fast);
 			return True;
 		}
@@ -1806,6 +1808,9 @@ UndoTiles(MlinkWidget w)
 				tile = w->mlink.spacePosition - 1;
 			if (MoveTilesDir(w, direction, tile, False, DOUBLE)) {
 				SetMlink(w, MLINK_UNDO);
+				if (CheckSolved(w)) {
+					SetMlink(w, MLINK_SOLVED);
+				}
 			} else {
 				char *buf1, *buf2;
 
@@ -2674,9 +2679,11 @@ SelectMlink(MlinkWidget w
 		w->mlink.currentFace = j;
 		w->mlink.currentRef = pos;
 		if (shift != 0 || w->mlink.practice || !CheckSolved(w)) {
-			pos = w->mlink.currentTile + w->mlink.currentFace * w->mlink.tiles;
-			DrawTile(w, pos, (w->mlink.tileOfPosition[i + j * w->mlink.tiles] <= 0),
-				 False, TRUE, 0, 0);
+			pos = w->mlink.currentTile +
+				w->mlink.currentFace * w->mlink.tiles;
+			DrawTile(w, pos, (w->mlink.tileOfPosition[i +
+				j * w->mlink.tiles] <= 0),
+				False, TRUE, 0, 0);
 		}
 	} else
 		w->mlink.currentRef = -w->mlink.tileFaces;
@@ -2748,8 +2755,9 @@ MotionMlink(MlinkWidget w
 		if (shift != 0 || w->mlink.practice || !CheckSolved(w)) {
 			pos = w->mlink.currentTile +
 				w->mlink.currentFace * w->mlink.tiles;
-			DrawTile(w, pos, (w->mlink.tileOfPosition[i + j * w->mlink.tiles] <= 0),
-				 False, TRUE, 0, 0);
+			DrawTile(w, pos, (w->mlink.tileOfPosition[i +
+				j * w->mlink.tiles] <= 0),
+				False, TRUE, 0, 0);
 		}
 	} else
 		w->mlink.currentRef = -w->mlink.tileFaces;
