@@ -13,7 +13,7 @@
 #  reverse better so it does not repeat last move of 3 tiles.
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 2003 - 2005    David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2006    David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -42,6 +42,10 @@
 #endif
 #include "MlinkP.h"
 
+#if 0
+#define DEBUG
+#endif
+
 #define LeftAway(w,r) MoveTilePiece(w,TOP,(r)?w->mlink.tiles-1:0,False) /* push top away */
 #define LeftAway2(w,r) MoveTilePiece(w,TOP,(r)?w->mlink.tiles-1:0,False);\
 			MoveTilePiece(w,TOP,(r)?w->mlink.tiles-1:0,False)
@@ -565,7 +569,7 @@ static void
 Swap32_31(MlinkWidget w, Boolean reverse)
 {
 	if (reverse) {
-		RightSlide(w, w->mlink.tiles - 1, reverse);
+		RightSlide(w, w->mlink.tiles - 1, !reverse);
 	}
 	RightAway(w, reverse);
 	RightSlide(w, 1, reverse);
@@ -1294,6 +1298,9 @@ SolveWhite(MlinkWidget w)
 	Boolean reverse = False;
 	int current, loc, pos;
 
+#ifdef DEBUG
+	(void) printf("SolveWhite\n");
+#endif
 	current = (w->mlink.faces - 1) * w->mlink.tiles;
 	if (w->mlink.tileOfPosition[current] - 1 != current) {
 		loc = findPiece(w, current);
@@ -1473,8 +1480,8 @@ SolveSpecialCases(MlinkWidget w, const int pos1, const int pos2)
 	int x_2 = pos2 % w->mlink.tiles;
 	int y_2 = pos2 / w->mlink.tiles;
 
-#if 0
-	printf("SolveSpecialCases pos %d, %d\n", pos1, pos2);
+#ifdef DEBUG
+	(void) printf("    SolveSpecialCases pos %d, %d\n", pos1, pos2);
 #endif
 	if (x_1 >= w->mlink.tiles / 2) {
 		x_1 = w->mlink.tiles - 1 - x_1;
@@ -1623,6 +1630,9 @@ SolveMiddleFromEnd(MlinkWidget w, int tile, int otherTile)
 	int face, otherFace, pos, otherPos;
 	Boolean found = True;
 
+#ifdef DEBUG
+	(void) printf("  SolveMiddleFromEnd %d, %d\n", tile, otherTile);
+#endif
 	while (found) {
 		found = False;
 		for (face = 0; face < w->mlink.faces - 1; face++) {
@@ -1644,6 +1654,9 @@ SolveEnd(MlinkWidget w, int tile)
 	int face, otherFace, pos, otherPos;
 	Boolean found = True;
 
+#ifdef DEBUG
+	(void) printf("  SolveEnd %d\n", tile);
+#endif
 	while (found) {
 		found = False;
 		for (face = 0; face < w->mlink.faces - 1; face++) {
@@ -1667,6 +1680,9 @@ SolveEnds(MlinkWidget w, int tile, int otherTile)
 	int face, pos, otherPos;
 	Boolean found = True;
 
+#ifdef DEBUG
+	(void) printf("  SolveEnds %d, %d\n", tile, otherTile);
+#endif
 	while (found) {
 		found = False;
 		for (face = 0; face < w->mlink.faces - 1; face++) {
@@ -1677,6 +1693,10 @@ SolveEnds(MlinkWidget w, int tile, int otherTile)
 			}
 		}
 	}
+#ifdef DEBUG
+	(void) printf("  Finished SolveEnds %d, %d\n", tile, otherTile);
+	/*sleep(2);*/
+#endif
 }
 
 static void
@@ -1685,6 +1705,9 @@ MatchLeftRight(MlinkWidget w, int tile, int otherTile)
 	int face, otherFace, pos, otherPos;
 	Boolean found = True;
 
+#ifdef DEBUG
+	(void) printf("  MatchLeftRight %d, %d\n", tile, otherTile);
+#endif
 	while (found) {
 		found = False;
 		for (face = 0; face < w->mlink.faces - 1; face++) {
@@ -1707,6 +1730,9 @@ ClearOut(MlinkWidget w, int tile, int otherTile, int shift)
 {
 	int face, otherFace, pos, otherPos;
 
+#ifdef DEBUG
+	(void) printf("  ClearOut %d, %d, %d\n", tile, otherTile, shift);
+#endif
 	for (face = 0; face < w->mlink.faces - 1; face++) {
 		pos = face * w->mlink.tiles + tile;
 		for (otherFace = 0; otherFace < w->mlink.faces - 1;
@@ -1724,6 +1750,9 @@ ClearOut(MlinkWidget w, int tile, int otherTile, int shift)
 static void
 SolveLeftMiddle(MlinkWidget w)
 {
+#ifdef DEBUG
+	(void) printf("SolveLeftMiddle\n");
+#endif
 	SolveMiddleFromEnd(w, 0, 1);
 	ClearOut(w, 1, 1, -1);
 	SolveMiddleFromEnd(w, 0, 1);
@@ -1737,6 +1766,9 @@ SolveLeftMiddle(MlinkWidget w)
 static void
 SolveLeft(MlinkWidget w)
 {
+#ifdef DEBUG
+	(void) printf("SolveLeft\n");
+#endif
 	SolveEnd(w, 0);
 	MatchLeftRight(w, 3, 0);
 	SolveEnds(w, 3, 0);
@@ -1748,6 +1780,9 @@ SolveLeft(MlinkWidget w)
 static void
 SolveRightMiddle(MlinkWidget w)
 {
+#ifdef DEBUG
+	(void) printf("SolveRightMiddle\n");
+#endif
 	SolveMiddleFromEnd(w, 3, 2);
 	ClearOut(w, 2, 2, 1);
 	SolveMiddleFromEnd(w, 3, 2);
@@ -1756,6 +1791,9 @@ SolveRightMiddle(MlinkWidget w)
 static void
 SolveRight(MlinkWidget w)
 {
+#ifdef DEBUG
+	(void) printf("SolveRight\n");
+#endif
 	SolveEnd(w, 3);
 }
 
