@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -86,106 +86,106 @@ static MlinkRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Mlink Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Mlink Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-tile {color}]\n"
-	"\t[-face{0|1|2|3|4|5|6|7} {color}] [-tiles {int}]\n"
-	"\t[-faces {int}] [-[no]orient] [-[no]pairs]\n"
-	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
-	"\t[-[no]sound] [-bumpSound {filename}] [-moveSound {filename}]\n"
-	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-face{0|1|2|3|4|5|6|7} {color}]\n"
+"[-{border|bd} {color}] [-[no]install]\n"
+"[-picture {filename}] [-delay msecs] [-[no]sound]\n"
+"[-bumpSound {filename}] [-moveSound {filename}]\n"
+"[-{font|fn} {fontname}] [-tiles {int}] [-faces {int}]\n"
+"[-[no]orient] [-[no]middle] [-base {int}]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"Ideal's The Missing Link, a 4x4 puzzle,  riding on the wave "
-	"of Rubik's Cube craze.  There are  many variations on this\n"
-	"theme, including the \"6x6\" puzzle and Babylon Tower.  What "
-	"makes the Missing Link a harder puzzle to solve is that the\n"
-	"2 center positions rotate together.\n"
+"Ideal's The Missing Link, a 4x4 puzzle,  riding on the wave "
+"of Rubik's Cube craze.  There are  many variations on this\n"
+"theme, including the \"6x6\" puzzle and Babylon Tower.  What "
+"makes the Missing Link a harder puzzle to solve is that the\n"
+"2 center positions rotate together.\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a tile. Release "
-	"\"mouse-left\" button in the same row would move the tile towards\n"
-	"the space (unless there is no space in that row).  "
-	"Release on a different row will move the tiles up or down.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle orient mode.  Slightly "
-	"more challenging on (default is off).\n"
-	"\n"
-	"Press \"M\" or \"m\" keys to toggle the middle mode.  All "
-	"the middle tiles rotate together.  This is considerably\n"
-	"more challenging on (default is on).\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"the mouse.\n"
-	"Key pad is defined for Missing Link as:\n"
-	"  8    Up\n"
-	"  ^\n"
-	"4< >6  Left, Right\n"
-	"  v\n"
-	"  2    Down\n"
-	"\n"
-	"Use the shift key and the up or down arrow keys to rotate "
-	"all the tiles.\n"
-	"\n"
-	"Use the control key and the keypad or arrow keys to reduce "
-	"or enlarge the complexity of the puzzle.\n"
+"Press \"mouse-left\" button to move a tile. Release "
+"\"mouse-left\" button in the same row would move the tile towards\n"
+"the space (unless there is no space in that row).  "
+"Release on a different row will move the tiles up or down.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle.\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle orient mode.  Slightly "
+"more challenging on (default is off).\n"
+"\n"
+"Press \"M\" or \"m\" keys to toggle the middle mode.  All "
+"the middle tiles rotate together.  This is considerably\n"
+"more challenging on (default is on).\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Missing Link as:\n"
+"  8    Up\n"
+"  ^\n"
+"4< >6  Left, Right\n"
+"  v\n"
+"  2    Down\n"
+"\n"
+"Use the shift key and the up or down arrow keys to rotate "
+"all the tiles.\n"
+"\n"
+"Use the control key and the keypad or arrow keys to reduce "
+"or enlarge the complexity of the puzzle.\n"
 };
 
 static const char referencesHelp[] = {
-	"L. E. Horden, Sliding Piece Puzzles (Recreations in "
-	"Mathematics Series), Oxford University\n"
-	"Press 1986, Plate X.\n"
-	"you are about to find the solution: The Missing Link, "
-	"Ideal Toy Corporation, 1981.\n"
+"L. E. Horden, Sliding Piece Puzzles (Recreations in "
+"Mathematics Series), Oxford University\n"
+"Press 1986, Plate X.\n"
+"you are about to find the solution: The Missing Link, "
+"Ideal Toy Corporation, 1981.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, only implemented "
-	"for tiles = 4 and faces = 4.\n"
+"Auto-solver: sorry, only implemented "
+"for tiles = 4 and faces = 4.\n"
 };
 
 #ifndef SCOREFILE
@@ -337,7 +337,7 @@ ReadRecords(void)
 				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
 					(void) fscanf(fp, "%d %s\n", &n, userName);
 					if (n <= mlinkRecord[l][k][j][i].score ||
-					    mlinkRecord[l][k][j][i].score <= NEVER) {
+						  mlinkRecord[l][k][j][i].score <= NEVER) {
 						mlinkRecord[l][k][j][i].score = n;
 						(void) strncpy(mlinkRecord[l][k][j][i].name,
 							userName, USERNAMELEN);
@@ -456,7 +456,7 @@ HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 	int k = (orient) ? 1 : 0, l = (middle) ? 1 : 0;
 
 	if (tiles <= MAXTILES && (counter < mlinkRecord[l][k][j][i].score ||
-			 mlinkRecord[l][k][j][i].score <= NEVER)) {
+			mlinkRecord[l][k][j][i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		mlinkRecord[l][k][j][i].score = counter;
 		(void) strncpy(mlinkRecord[l][k][j][i].name, userNameDsp,
@@ -551,7 +551,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1062,15 +1068,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1137,8 +1143,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
