@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -90,134 +90,133 @@ static OctRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Oct Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Oct Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5|6|7} {color}]\n"
-	"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n"
-	"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n"
-	"\t[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-	"\t[-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-face{0|1|2|3|4|5|6|7} {color}] [-{border|bd} {color}]\n"
+"[-{font|fn} {fontname}] [-{size {int} | sticky}]\n"
+"[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original puzzle has 9 triangles per face (size = 3) "
-	"and has period 4 turning (i.e. the face or points turn\n"
-	"in 90 degree intervals).  The puzzle was designed by Uwe "
-	"Meffert and called the Magic Octahedron (or Star\n"
-	"Puzzler).  The puzzle was not widely distributed but not "
-	"exactly rare.  This puzzle has some analogies to the\n"
-	"Rubik's Cube and the solving techniques are the same to "
-	"that of the Pyraminx.  Christoph's Magic Jewel is\n"
-	"similar except there are no trivial corners to solve.  "
-	"This has 2^22*12! or 2,009,078,326,886,400 different\n"
-	"combinations.\n"
-	"Uwe Meffert also noticed that there could be an "
-	"alternate twisting for the octahedron where it has\n"
-	"period 3 turning (i.e. faces turn with 120 degree "
-	"intervals).\n"
-	"One is able to simulate a Trajber's Octahedron (period "
-	"3 turning and sticky mode).  Also one is able to\n"
-	"simulate one with variant turning (period 4 turning and "
-	"sticky mode).\n"
+"The original puzzle has 9 triangles per face (size = 3) "
+"and has period 4 turning (i.e. the face or points turn\n"
+"in 90 degree intervals).  The puzzle was designed by Uwe "
+"Meffert and called the Magic Octahedron (or Star\n"
+"Puzzler).  The puzzle was not widely distributed but not "
+"exactly rare.  This puzzle has some analogies to the\n"
+"Rubik's Cube and the solving techniques are the same to "
+"that of the Pyraminx.  Christoph's Magic Jewel is\n"
+"similar except there are no trivial corners to solve.  "
+"This has 2^22*12! or 2,009,078,326,886,400 different\n"
+"combinations.\n"
+"Uwe Meffert also noticed that there could be an "
+"alternate twisting for the octahedron where it has\n"
+"period 3 turning (i.e. faces turn with 120 degree "
+"intervals).\n"
+"One is able to simulate a Trajber's Octahedron (period "
+"3 turning and sticky mode).  Also one is able to\n"
+"simulate one with variant turning (period 4 turning and "
+"sticky mode).\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece on the same face and\n"
-	"in the same row (but not an adjacent piece or the move "
-	"is ambiguous).  The pieces will then turn towards\n"
-	"where the mouse button was released.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
-	"\n"
-	"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
-	"has to orient the faces in orient mode, besides\n"
-	"getting all the faces to be the same color.  To do this "
-	"one has to get the lines to be oriented in\n"
-	"the same direction, this only matters with center "
-	"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
-	"corner or edge).  This does add complexity so there are "
-	"2 sets of records.\n"
-	"\n"
-	"Press \"3\", \"4\", \"B\", or \"b\" keys (not the keypad 3, 4) "
-	"to change modes to Period 3, Period 4, or Both.\n"
-	"\n"
-	"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
-	"is disabled here if sticky mode is on).\n"
-	"\"Sticky\" and \"Period 3\" turning allows only the faces to "
-	"turn.  It is as if the middle cut of the three cuts\n"
-	"did not exist.\n"
-	"\"Sticky\" and \"Period 4\" turning allows only the points to "
-	"turn, it is as if the middle cut of the three cuts\n"
-	"did not exist.\n"
-	"Beware, the \"Sticky\" mode is a hack and much could be done "
-	"to improve its look.\n"
-	"\n"
-	"Press \"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"mouse clicks.\n"
-	"Key pad is defined for Oct as:\n"
-	"  /    Counterclockwise\n"
-	"7 8 9  Up, Upper Right\n"
-	"  ^\n"
-	"4<5>6  Left, Clockwise, Right\n"
-	"  v\n"
-	"1 2 3  Lower Left, Down\n"
-	"\n"
-	"Use the shift keys to access \"Period 4\" turns from "
-	"\"Both\" mode, otherwise it assumes \"Period 3\" turning.\n"
-	"Points turn in \"Period 4\" and faces turn in \"Period 3\".\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys to move the whole octahedron.  This is not\n"
-	"recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece on the same face and\n"
+"in the same row (but not an adjacent piece or the move "
+"is ambiguous).  The pieces will then turn towards\n"
+"where the mouse button was released.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
+"has to orient the faces in orient mode, besides\n"
+"getting all the faces to be the same color.  To do this "
+"one has to get the lines to be oriented in\n"
+"the same direction, this only matters with center "
+"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
+"corner or edge).  This does add complexity so there are "
+"2 sets of records.\n"
+"\n"
+"Press \"3\", \"4\", \"B\", or \"b\" keys (not the keypad 3, 4) "
+"to change modes to Period 3, Period 4, or Both.\n"
+"\n"
+"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
+"is disabled here if sticky mode is on).\n"
+"\"Sticky\" and \"Period 3\" turning allows only the faces to "
+"turn.  It is as if the middle cut of the three cuts\n"
+"did not exist.\n"
+"\"Sticky\" and \"Period 4\" turning allows only the points to "
+"turn, it is as if the middle cut of the three cuts\n"
+"did not exist.\n"
+"Beware, the \"Sticky\" mode is a hack and much could be done "
+"to improve its look.\n"
+"\n"
+"Press \"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Oct as:\n"
+"  /    Counterclockwise\n"
+"7 8 9  Up, Upper Right\n"
+"  ^\n"
+"4<5>6  Left, Clockwise, Right\n"
+"  v\n"
+"1 2 3  Lower Left, Down\n"
+"\n"
+"Use the shift keys to access \"Period 4\" turns from "
+"\"Both\" mode, otherwise it assumes \"Period 3\" turning.\n"
+"Points turn in \"Period 4\" and faces turn in \"Period 3\".\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys to move the whole octahedron.  This is not\n"
+"recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
-	"God knows what else by Douglas R. Hofstadter,\n"
-	"Scientific American, July 1982, pp 16-31.\n"
-	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
+"God knows what else by Douglas R. Hofstadter,\n"
+"Scientific American, July 1982, pp 16-31.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -296,7 +295,7 @@ PrintRecords(void)
 			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
 				if (octRecord[mode][orient][i].score > 0)
 					(void) printf("%4d%7d%6d %-12s%9d\n",
-						mode + 3, orient, i + 1, 
+						mode + 3, orient, i + 1,
 						octRecord[mode][orient][i].name,
 						octRecord[mode][orient][i].score);
 			}
@@ -492,7 +491,7 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 
 	if ((sticky || size <= MAXFACETS) &&
 			(counter < octRecord[i][j][k].score ||
-	    		octRecord[i][j][k].score <= NEVER)) {
+			octRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		octRecord[i][j][k].score = counter;
 		(void) strncpy(octRecord[i][j][k].name, userNameDsp, USERNAMELEN);
@@ -583,7 +582,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1105,15 +1110,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1176,8 +1181,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
@@ -1313,12 +1324,12 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 	Boolean orient, sticky = cbs->set, practice;
 
 	XtVaGetValues(oct,
-		      XtNsize, &size,
-		      XtNmode, &mode,
-		      XtNorient, &orient,
-		      XtNpractice, &practice, NULL);
+		XtNsize, &size,
+		XtNmode, &mode,
+		XtNorient, &orient,
+		XtNpractice, &practice, NULL);
 	XtVaSetValues(oct,
-		      XtNsticky, sticky, NULL);
+		XtNsticky, sticky, NULL);
 	if ((sticky && size != 4) || (!sticky && oldSize != 4)) {
 		if (sticky)
 			size = 4;
