@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -144,12 +144,18 @@ static XtActionsRec actionsListPanex[] =
 
 static XtResource resourcesPanex[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(PanexWidget, panex.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(PanexWidget, panex.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(PanexWidget, core.width),
+	 XtRString, (caddr_t) "400"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(PanexWidget, core.height),
+	 XtRString, (caddr_t) "200"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -162,33 +168,15 @@ static XtResource resourcesPanex[] =
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.tileColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultBackground*/},
-	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(PanexWidget, panex.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNpyramidColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.pyramidName[0]),
 	 XtRString, (caddr_t) "magenta"},
 	{XtNpyramidColor1, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.pyramidName[1]),
 	 XtRString, (caddr_t) "yellow"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(PanexWidget, core.width),
-	 XtRString, (caddr_t) "400"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(PanexWidget, core.height),
-	 XtRString, (caddr_t) "200"},
-	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
-	 XtOffset(PanexWidget, panex.tiles),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTTILES */
-	{XtNmode, XtCMode, XtRInt, sizeof (int),
-	 XtOffset(PanexWidget, panex.mode),
-	 XtRString, (caddr_t) "1"}, /* DEFAULTMODE */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(PanexWidget, panex.mono),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(PanexWidget, panex.reverse),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(PanexWidget, panex.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.delay),
 	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
@@ -201,12 +189,18 @@ static XtResource resourcesPanex[] =
 	{XtNfont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.font),
 	 XtRString, (caddr_t) "9x15bold"},
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(PanexWidget, panex.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(PanexWidget, panex.cheat),
-	 XtRString, (caddr_t) "FALSE"},
+	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
+	 XtOffset(PanexWidget, panex.tiles),
+	 XtRString, (caddr_t) "10"}, /* DEFAULTTILES */
+	{XtNmode, XtCMode, XtRInt, sizeof (int),
+	 XtOffset(PanexWidget, panex.mode),
+	 XtRString, (caddr_t) "1"}, /* DEFAULTMODE */
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(PanexWidget, panex.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(PanexWidget, panex.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PanexWidget, panex.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
@@ -216,6 +210,12 @@ static XtResource resourcesPanex[] =
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.menu),
 	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.cheat),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(PanexWidget, panex.select), XtRCallback, (caddr_t) NULL}
 };
@@ -645,7 +645,8 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 		/* Draw Slots */
 		FILLRECTANGLE(w, dr, w->panex.inverseGC,
 			dx, dy,
-			w->panex.tileSize.x, w->panex.tileSize.y);
+			w->panex.tileSize.x + 1,
+			w->panex.tileSize.y + 1 - pressedOffset);
 		if (j == 0) {
 			if (i == 0) {
 				FILLRECTANGLE(w, dr, w->panex.borderGC,
@@ -672,10 +673,10 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 			}
 			FILLRECTANGLE(w, dr, w->panex.borderGC,
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
-				dy + w->panex.tileSize.y / 3 - 1 - pressedOffset,
+				dy + w->panex.tileSize.y / 3 - 1,
 				w->panex.tileSize.x / 3,
 				w->panex.tileSize.y - w->panex.tileSize.y / 3 +
-				1 + pressedOffset);
+				2 - pressedOffset);
 		} else if (j == w->panex.tiles) {
 			FILLRECTANGLE(w, dr, w->panex.borderGC,
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
@@ -687,7 +688,7 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
 				dy - pressedOffset,
 				w->panex.tileSize.x / 3,
-				w->panex.tileSize.y + pressedOffset);
+				w->panex.tileSize.y + pressedOffset + 1);
 		}
 		return;
 	}
@@ -782,7 +783,7 @@ AnimateSlide(PanexWidget w, int currentStack, int currentPosition,
 	if (diffPosition > 0) {
 		dir = BOTTOM;
 		spaces = diffPosition;
-		moveI = w->panex.pos.y; 
+		moveI = w->panex.pos.y;
 	} else if (diffPosition < 0) {
 		dir = TOP;
 		spaces = -diffPosition;
@@ -817,6 +818,9 @@ AnimateSlide(PanexWidget w, int currentStack, int currentPosition,
 			if ((dir == RIGHT) || (dir == LEFT)) {
 				ix = ((dir == RIGHT) ? inc : -inc);
 				iy = 0;
+				DrawSlot(w, currentStack,
+					dx, dy + w->panex.tileSize.y,
+					w->panex.tileSize.x + 1, 1);
 			} else if ((dir == TOP) || (dir == BOTTOM)) {
 				ix = 0;
 				iy = ((dir == BOTTOM) ? inc : -inc);
@@ -916,7 +920,8 @@ TopOfStack(PanexWidget w, int stack, int start)
 }
 
 static int
-RequestMove(PanexWidget w, int fromStack, int fromPosition, int toStack)
+RequestMove(PanexWidget w, int fromStack, int fromPosition, int toStack,
+		Boolean limbo)
 {
 	int i;
 
@@ -939,7 +944,7 @@ RequestMove(PanexWidget w, int fromStack, int fromPosition, int toStack)
 	}
 	i = (i == -1) ? w->panex.tiles : i - 1;
 	if (w->panex.mode == HANOI) {
-		if (i == w->panex.tiles ||
+		if (i == w->panex.tiles || limbo ||
 				w->panex.tileOfPosition[toStack][i + 1].loc >=
 				w->panex.tileOfPosition[fromStack][fromPosition].loc)
 			return i;
@@ -1002,16 +1007,16 @@ DiscreteMoves(PanexWidget w, int currentStack, int currentPosition,
 
 static void
 SlideTile(PanexWidget w, int fromStack, int fromPosition,
-		int toStack, int toPosition)
+		int toStack, int toPosition, int fast)
 {
 	int currentStack = fromStack, currentPosition = fromPosition;
 	int nextStack = fromStack, nextPosition = fromPosition;
 
 	if (currentPosition > 0) {
-		if (w->panex.delay > 0) {
+		if (fast != INSTANT && w->panex.delay > 0) {
 			nextPosition = 0;
 			AnimateSlide(w, currentStack, currentPosition,
-				nextStack, nextPosition, NORMAL);
+				nextStack, nextPosition, fast);
 			VirtualMove(w, currentStack, currentPosition,
 				nextStack, nextPosition);
 			currentPosition = nextPosition;
@@ -1030,10 +1035,10 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition,
 #endif
 	}
 	if (currentStack != toStack) {
-		if (w->panex.delay > 0) {
+		if (fast != INSTANT && w->panex.delay > 0) {
 			nextStack = toStack;
 			AnimateSlide(w, currentStack, currentPosition,
-				nextStack, nextPosition, NORMAL);
+				nextStack, nextPosition, fast);
 			VirtualMove(w, currentStack, currentPosition,
 				nextStack, nextPosition);
 			currentStack = nextStack;
@@ -1054,10 +1059,10 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition,
 #endif
 	}
 	if (currentPosition < toPosition) {
-		if (w->panex.delay > 0) {
+		if (fast != INSTANT && w->panex.delay > 0) {
 			nextPosition = toPosition;
 			AnimateSlide(w, currentStack, currentPosition,
-				nextStack, nextPosition, NORMAL);
+				nextStack, nextPosition, fast);
 			VirtualMove(w, currentStack, currentPosition,
 				nextStack, nextPosition);
 			currentPosition = nextPosition;
@@ -1078,23 +1083,26 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition,
 }
 
 static int
-MoveTile(PanexWidget w, int fromStack, int fromPosition, int toStack)
+MoveTile(PanexWidget w, int fromStack, int fromPosition, int toStack, int fast)
 {
 	int toPosition;
 
-	if ((toPosition = RequestMove(w, fromStack, fromPosition, toStack)) >= 0)
-		SlideTile(w, fromStack, fromPosition, toStack, toPosition);
+	if ((toPosition = RequestMove(w, fromStack, fromPosition, toStack,
+			False)) >= 0)
+		SlideTile(w, fromStack, fromPosition, toStack, toPosition,
+			fast);
 	return toPosition;
 }
 
 static Boolean
-MoveTileToLimbo(PanexWidget w, int fromStack, int fromPosition, int toStack)
+MoveTileToLimbo(PanexWidget w, int fromStack, int fromPosition, int toStack,
+		Boolean limbo)
 {
 	Boolean aMove;
 
-	aMove = (RequestMove(w, fromStack, fromPosition, toStack) >= 0);
+	aMove = (RequestMove(w, fromStack, fromPosition, toStack, limbo) >= 0);
 	if (aMove)
-		SlideTile(w, fromStack, fromPosition, toStack, 0);
+		SlideTile(w, fromStack, fromPosition, toStack, 0, NORMAL);
 	return aMove;
 }
 
@@ -1339,7 +1347,8 @@ UndoTiles(PanexWidget w)
 
 		GetMove(&toStack, &fromStack);
 		if ((fromPosition = TopOfStack(w, fromStack, 0)) < 0 ||
-				MoveTile(w, fromStack, fromPosition, toStack) < 0) {
+				MoveTile(w, fromStack, fromPosition, toStack,
+					DOUBLE) < 0) {
 			char *buf1, *buf2;
 
 			intCat(&buf1, "Move from ", fromStack);
@@ -1416,11 +1425,13 @@ ModeTiles(PanexWidget w)
 }
 
 int
-MovePanex(PanexWidget w, int fromStack, int fromPosition, int toStack)
+MovePanex(PanexWidget w, int fromStack, int fromPosition, int toStack,
+		int fast)
 {
 	int	 toPosition;
 
-	if ((toPosition = MoveTile(w, fromStack, fromPosition, toStack)) >= 0) {
+	if ((toPosition = MoveTile(w, fromStack, fromPosition, toStack,
+			fast)) >= 0) {
 		SetPanex(w, PANEX_MOVED);
 		PutMove(fromStack, toStack);
 	}
@@ -2054,8 +2065,12 @@ SelectPanex(PanexWidget w
 		   ((w->panex.currentPosition = TopOfStack(w, stack, 0)) >= 0)) {
 		w->panex.currentStack = stack;
 		if (MoveTileToLimbo(w, w->panex.currentStack,
-		    w->panex.currentPosition, w->panex.currentStack)) {
-			w->panex.currentPosition = 0; 
+		    w->panex.currentPosition, w->panex.currentStack, False)) {
+			w->panex.currentPosition = 0;
+			w->panex.previousStack = w->panex.currentStack;
+		} else if (MoveTileToLimbo(w, w->panex.currentStack,
+		    w->panex.currentPosition, w->panex.currentStack, True)) {
+			w->panex.currentPosition = 0;
 			w->panex.previousStack = w->panex.currentStack;
 		}
 		DrawTile(w, stack, w->panex.currentPosition, False,
@@ -2087,7 +2102,7 @@ MotionPanex(PanexWidget w
 	if ((toStack = SelectTile(w, x)) >= 0 &&
 			toStack != w->panex.currentStack) {
 		if (MoveTileToLimbo(w, w->panex.currentStack,
-				w->panex.currentPosition, toStack)) {
+				w->panex.currentPosition, toStack, True)) {
 #if 0
 	DrawTile(w, w->panex.currentStack, w->panex.currentPosition,
 		True, TRUE, 0, 0);
@@ -2095,8 +2110,18 @@ MotionPanex(PanexWidget w
 			if (w->panex.previousStack < 0) {
 				w->panex.previousStack = w->panex.currentStack;
 			}
-			w->panex.currentStack = toStack; 
-			w->panex.currentPosition = 0; 
+			w->panex.currentStack = toStack;
+			w->panex.currentPosition = 0;
+			DrawTile(w, toStack, w->panex.currentPosition, False,
+				TRUE, 0, 0);
+		} else if (MoveTileToLimbo(w, w->panex.currentStack,
+				w->panex.currentPosition, toStack, False)) {
+#if 0
+	DrawTile(w, w->panex.currentStack, w->panex.currentPosition,
+		True, TRUE, 0, 0);
+#endif
+			w->panex.currentStack = toStack;
+			w->panex.currentPosition = 0;
 			DrawTile(w, toStack, w->panex.currentPosition, False,
 				TRUE, 0, 0);
 		}
@@ -2131,7 +2156,8 @@ ReleasePanex(PanexWidget w
 			toStack != w->panex.currentStack) ||
 			(w->panex.previousStack >= 0))) {
 		if ((toPosition = MoveTile(w, w->panex.currentStack,
-				w->panex.currentPosition, toStack)) >= 0) {
+				w->panex.currentPosition, toStack,
+				NORMAL)) >= 0) {
 			if (w->panex.previousStack != toStack) {
 				SetPanex(w, PANEX_MOVED);
 				if (w->panex.previousStack >= 0) {
@@ -2148,7 +2174,7 @@ ReleasePanex(PanexWidget w
 		  if (w->panex.previousStack != -1) {
 		    if ((toPosition = MoveTile(w, w->panex.currentStack,
 			w->panex.currentPosition,
-			w->panex.currentStack)) >= 0) {
+			w->panex.currentStack, NORMAL)) >= 0) {
 		      if (w->panex.previousStack != toStack &&
 			  w->panex.previousStack != w->panex.currentStack) {
 				SetPanex(w, PANEX_MOVED);
@@ -2166,22 +2192,9 @@ ReleasePanex(PanexWidget w
 		} else {
 		  SetPanex(w, PANEX_ILLEGAL);
 		  if (w->panex.previousStack != -1) {
-		    if ((toPosition = MoveTile(w, w->panex.currentStack,
+		    toPosition = MoveTile(w, w->panex.currentStack,
 			w->panex.currentPosition,
-			w->panex.currentStack)) >= 0) {
-		      if (w->panex.previousStack != toStack &&
-			  w->panex.previousStack != w->panex.currentStack) {
-				SetPanex(w, PANEX_MOVED);
-				if (w->panex.previousStack >= 0) {
-				  PutMove(w->panex.previousStack, toStack);
-				} else {
-				  PutMove(w->panex.currentStack, toStack);
-				}
-				if (CheckSolved(w)) {
-					SetPanex(w, PANEX_SOLVED);
-				}
-			}
-		    }
+			w->panex.previousStack, NORMAL);
 		  }
 		}
 	}
