@@ -85,13 +85,13 @@ extern PanexClassRec panexClassRec;
 #define RIGHT 1
 #define BOTTOM 2
 #define LEFT 3
-#define COORD 4     
-        
+#define COORD 4
+
 #define MAXSLICES 10
-        
-#define NORMAL 1    
+
+#define NORMAL 1
 #define DOUBLE 2
-#define INSTANT 3   
+#define INSTANT 3
 
 typedef struct _PanexLoc {
 	int         stack, loc;
@@ -138,7 +138,7 @@ typedef struct _PanexRec {
 extern PanexLoc *startLoc[MAXSTACKS - 1];
 extern void SetPanex(PanexWidget w, int reason);
 extern int  MovePanex(PanexWidget w, int fromStack, int fromPosition,
-	int toStack);
+	int toStack, int fast);
 
 extern void SolveTilesFromStart(PanexWidget w);
 extern void DrawAllTiles(PanexWidget w);
