@@ -131,7 +131,7 @@ MoveATile(PanexWidget w, int fromStack, int toStack)
 		longjmp(solve_env, 1);
 #endif
 	if ((fromPosition = TopOfStack(w, fromStack, 0)) < 0 ||
-	    MovePanex(w, fromStack, fromPosition, toStack) < 0) {
+	    MovePanex(w, fromStack, fromPosition, toStack, NORMAL) < 0) {
 		(void) printf("move from %d to %d can not be made.",
 			      fromStack, toStack);
 		return False;
