@@ -184,7 +184,7 @@ ScanMoves(FILE * fp, PanexWidget w, int moves)
 		(void) printf("%d %d\n", fromStack, toStack);
 #endif
 		if ((fromPosition = TopOfStack(w, fromStack, 0)) < 0 ||
-		    MovePanex(w, fromStack, fromPosition, toStack) < 0)
+		    MovePanex(w, fromStack, fromPosition, toStack, INSTANT) < 0)
 			(void) fprintf(stderr,
 				"%d move from %d to %d can not be made.",
 				l, fromStack, toStack);
