@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -86,100 +86,102 @@ static PanexRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Panex Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
-	"I got some help from Rene Jansen <rene.j.jansen@bigfoot.com> "
-	"and Nick Baxter <nickb@baxterweb.com>.\n"
+"Panex Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
+"I got some help from Rene Jansen <rene.j.jansen@bigfoot.com> "
+"and Nick Baxter <nickb@baxterweb.com>.\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-tile {color}] [-pyramid{0|1} {color}]\n"
-	"\t[-tiles {int}] [-{mode {int}|hanoi|panex}] [-delay msecs]\n"
-	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-pyramid{0|1} {color}]\n"
+"[-{border|bd} {color}] [-delay msecs] [-[no]sound]\n"
+"[-moveSound {filename}] [-{font|fn} {fontname}]\n"
+"[-tiles {int}] [-{mode {int}|hanoi|panex}]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original Panex puzzle is from the Japanese Magic Company "
-	"estimated from the 1980's.  Mathematicians at Bell\n"
-	"Laboratories estimated the number of moves to swap 2 columns "
-	"of order 10 to be  27,564 <= N <= 31,537.  It came\n"
-	"in two varieties: one with a magenta and a yellow pyramid "
-	"of order 10 on silver tiles; in the gold version, the\n"
-	"gold version pieces of each color look alike (i.e. no "
-	"pyramid is drawn on them), this is a little harder.\n"
-	"The original Tower of Hanoi puzzle is the invention of "
-	"Edouard Lucas and temple of Benares of the god Brahma is\n"
-	"also his invention.\n"
+"The original Panex puzzle is from the Japanese Magic Company "
+"estimated from the 1980's.  Mathematicians at Bell\n"
+"Laboratories estimated the number of moves to swap 2 columns "
+"of order 10 to be  27,564 <= N <= 31,537.  It came\n"
+"in two varieties: one with a magenta and a yellow pyramid "
+"of order 10 on silver tiles; in the gold version, the\n"
+"gold version pieces of each color look alike (i.e. no "
+"pyramid is drawn on them), this is a little harder.\n"
+"The original Tower of Hanoi puzzle is the invention of "
+"Edouard Lucas and temple of Benares of the god Brahma is\n"
+"also his invention.\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a tile in the top tile "
-	"of a column.  Release \"mouse-left\" button on\n"
-	"another column to move the tile to that column.  It will "
-	"not move if blocked.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"C\", \"c\", \"R\","
-	"or \"r\" keys, to clear/reset the puzzle.\n"
-	"\n"
-	"Press \"M\" or \"m\" keys to toggle between hanoi "
-	"(one pyramid column) and panex (two pyramid columns) modes\n"
-	"(they each have different rules).\n"
-	"In Hanoi, one can not place  larger trapezoid on a smaller "
-	"trapezoid.  Here the goal is to move the pile from\n"
-	"the left peg to the rightmost peg.\n"
-	"In Panex, a tile can not go lower that its initial starting "
-	"point.  Here the goal is to exchange the 2 piles.\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
-	"\n"
-	"Press \"D\" or \"d\" keys to decrease the number of tiles.\n"
-	"\n"
-	"Press \"S\" or \"s\" keys to auto-solve.  Unfortunately, its "
-	"only implemented from the starting position.\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Unlike other puzzles in the collection there is no way to "
-	"move pieces without drag and drop.\n"
+"Press \"mouse-left\" button to move a tile in the top tile "
+"of a column.  Release \"mouse-left\" button on\n"
+"another column to move the tile to that column.  It will "
+"not move if blocked.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"C\", \"c\", \"R\","
+"or \"r\" keys, to clear/reset the puzzle.\n"
+"\n"
+"Press \"M\" or \"m\" keys to toggle between hanoi "
+"(one pyramid column) and panex (two pyramid columns) modes\n"
+"(they each have different rules).\n"
+"In Hanoi, one can not place  larger trapezoid on a smaller "
+"trapezoid.  Here the goal is to move the pile from\n"
+"the left peg to the rightmost peg.\n"
+"In Panex, a tile can not go lower that its initial starting "
+"point.  Here the goal is to exchange the 2 piles.\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of tiles.\n"
+"\n"
+"Press \"S\" or \"s\" keys to auto-solve.  Unfortunately, its "
+"only implemented from the starting position.\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Unlike other puzzles in the collection there is no way to "
+"move pieces without drag and drop.\n"
 };
 
 static const char referencesHelp[] = {
-	"Mark Manasse & Danny Sleator of AT&T Bell Laboratories  "
-	"and Victor K. Wei of Bell Communications Research,\n"
-	"Some Results on the Panex Puzzle, Murray Hill, NJ, 1985 "
-	"20 pp. (unpublished).\n"
-	"Vladimir Dubrovsky,  Nesting Puzzles  Part 1: Moving oriental "
-	" Quantum  January/February  1996  pp 55-57,\n"
-	"50-51.\n"
-	"L.  E.  Horden,  Sliding  Piece  Puzzles  (Recreations  in  "
-	"Mathematics  Series),  Oxford University Press  1986,\n"
-	"pp 144, 145.\n"
-	"Jerry Slocum & Jack Botermans,  Puzzles Old & New (How to Make "
-	"and  Solve Them),  University of Washington\n"
-	"Press, Seattle 1987, p 135.\n"
+"Mark Manasse & Danny Sleator of AT&T Bell Laboratories  "
+"and Victor K. Wei of Bell Communications Research,\n"
+"Some Results on the Panex Puzzle, Murray Hill, NJ, 1985 "
+"20 pp. (unpublished).\n"
+"Vladimir Dubrovsky,  Nesting Puzzles  Part 1: Moving oriental "
+" Quantum  January/February  1996  pp 55-57,\n"
+"50-51.\n"
+"L.  E.  Horden,  Sliding  Piece  Puzzles  (Recreations  in  "
+"Mathematics  Series),  Oxford University Press  1986,\n"
+"pp 144, 145.\n"
+"Jerry Slocum & Jack Botermans,  Puzzles Old & New (How to Make "
+"and  Solve Them),  University of Washington\n"
+"Press, Seattle 1987, p 135.\n"
 };
 #endif
 
@@ -328,7 +330,7 @@ ReadRecords(void)
 		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
 			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= panexRecord[mode][i].score ||
-			    panexRecord[mode][i].score <= NEVER) {
+					panexRecord[mode][i].score <= NEVER) {
 				panexRecord[mode][i].score = n;
 				(void) strncpy(panexRecord[mode][i].name,
 					userName, USERNAMELEN);
@@ -512,7 +514,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -837,15 +845,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -908,8 +916,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
