@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -90,152 +90,151 @@ static PyraminxRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Pyraminx Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Pyraminx Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-face{0|1|2|3} {color}]\n"
-	"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n"
-	"\t[-[no]orient] [-[no]practice] [-delay msecs]\n"
-	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-face{0|1|2|3} {color}] [-{border|bd} {color}]\n"
+"[-delay msecs] [-{font|fn} {fontname}]\n"
+"[-{size {int} | sticky}] [-{mode {int} | both}]\n"
+"[-[no]orient] [-[no]practice] [-userName {string}]\n"
+"[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original puzzle has 9 triangles per face (size = 3) "
-	"and has period 3 turning (i.e. the face or points turn\n"
-	"in 120 degree intervals).  The puzzle was designed by Uwe "
-	"Meffert and called the Pyraminx.  This has 2^5*3^8*6!/2\n"
-	"or 75,582,720 different combinations.\n"
-	"Another puzzle Senior Pyraminx 3x3x3 exists only on "
-	"paper, it has period 2 turning (i.e.  edges turn with\n"
-	"180 degree intervals) but the corners would fall off "
-	"unless it had some tricky mechanism.  (This may be the\n"
-	"same as the Master Pyraminx which has 446,965,972,992,000 "
-	"different combinations).\n"
-	"Another puzzle (which was not widely distributed), the "
-	"Junior Pyraminx (and similarly the Junior Pyraminx Star,\n"
-	"a octahedron formed by two tetrahedra, this has 7!*3^6 or "
-	"3,674,160 different combinations), has 4 triangles\n"
-	"(size = 2) per face.  This puzzle has been recently "
-	"reissued by Meffert as Pyramorphix\n"
-	"(http://www.mefferts-puzzles.com). At the time I designed "
-	"this computer puzzle thought that it had only period 2\n"
-	"turning (i.e the edges rotate).  It turns out the puzzle "
-	"has a period 4 turning (edges turn with 90 degree\n"
-	"intervals) which makes it analogous to the 2x2x2 Rubik's "
-	"cube.  This puzzle makes various non-tetrahedral shapes.\n"
-	"The puzzle contained here has no period 4 turning "
-	"flexability.\n"
-	"One is able to simulate Halpern's Tetrahedron or Pyraminx "
-	"Tetrahedron (period 3 turning and sticky mode).   Also one\n"
-	"is able to simulate one with variant turning (period 2 "
-	"turning and sticky mode).\n"
+"The original puzzle has 9 triangles per face (size = 3) "
+"and has period 3 turning (i.e. the face or points turn\n"
+"in 120 degree intervals).  The puzzle was designed by Uwe "
+"Meffert and called the Pyraminx.  This has 2^5*3^8*6!/2\n"
+"or 75,582,720 different combinations.\n"
+"Another puzzle Senior Pyraminx 3x3x3 exists only on "
+"paper, it has period 2 turning (i.e.  edges turn with\n"
+"180 degree intervals) but the corners would fall off "
+"unless it had some tricky mechanism.  (This may be the\n"
+"same as the Master Pyraminx which has 446,965,972,992,000 "
+"different combinations).\n"
+"Another puzzle (which was not widely distributed), the "
+"Junior Pyraminx (and similarly the Junior Pyraminx Star,\n"
+"a octahedron formed by two tetrahedra, this has 7!*3^6 or "
+"3,674,160 different combinations), has 4 triangles\n"
+"(size = 2) per face.  This puzzle has been recently "
+"reissued by Meffert as Pyramorphix\n"
+"(http://www.mefferts-puzzles.com). At the time I designed "
+"this computer puzzle thought that it had only period 2\n"
+"turning (i.e the edges rotate).  It turns out the puzzle "
+"has a period 4 turning (edges turn with 90 degree\n"
+"intervals) which makes it analogous to the 2x2x2 Rubik's "
+"cube.  This puzzle makes various non-tetrahedral shapes.\n"
+"The puzzle contained here has no period 4 turning "
+"flexability.\n"
+"One is able to simulate Halpern's Tetrahedron or Pyraminx "
+"Tetrahedron (period 3 turning and sticky mode).   Also one\n"
+"is able to simulate one with variant turning (period 2 "
+"turning and sticky mode).\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece on the same face and\n"
-	"in the same row (but not an adjacent piece or the move "
-	"is ambiguous).  The pieces will then turn towards\n"
-	"where the mouse button was released.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
-	"\n"
-	"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
-	"has to orient the faces in orient mode, besides\n"
-	"getting all the faces to be the same color.  To do this "
-	"one has to get the lines to be oriented in\n"
-	"the same direction, this only matters with center "
-	"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
-	"corner or edge).  This does add complexity so there are "
-	"2 sets of records.\n"
-	"\n"
-	"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad 2, 3) "
-	"to change modes to Period 2, Period 3, or Both.\n"
-	"\n"
-	"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
-	"is disabled here if sticky mode is on).\n"
-	"\"Sticky\" and \"Period 2\" turning allows only the edges to "
-	"turn, and the 2 center rows turn together. It is as if\n"
-	"the middle cut of the three cuts did not exist.\n"
-	"\"Sticky\" and \"Period 3\" turning allows only the faces to "
-	"turn, it is as if the middle cut of the three cuts\n"
-	"did not exist.\n"
-	"Beware, the \"Sticky\" mode is a hack and much could be done "
-	"to improve its look.\n"
-	"\n"
-	"Press \"S\" or \"s\" keys to start auto-solver.  Only works on "
-	"1x1x1, 2x2x2, and 3x3x3 pyrmaminxs in Period 3 mode.\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"mouse clicks.\n"
-	"Key pad is defined for Pyraminx as:\n"
-	"  /    Counterclockwise\n"
-	"  8 9  Up, Upper Right\n"
-	"  ^\n"
-	"4<5>6  Left, Clockwise, Right\n"
-	"  v\n"
-	"1 2    Lower Left, Down\n"
-	"Use the shift keys to access \"Period 3\" turns from "
-	"\"Both\" mode, otherwise it assumes \"Period 2\" turning.\n"
-	"Faces and points turn in \"Period 3\" and edges (2 points) "
-	"turn in \"Period 2\".\n"
-	"\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys to move the whole tetrahedron.  This is not\n"
-	"recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece on the same face and\n"
+"in the same row (but not an adjacent piece or the move "
+"is ambiguous).  The pieces will then turn towards\n"
+"where the mouse button was released.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode (in practice mode the\n"
+"record should say \"practice\").  This is good for learning "
+"moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
+"has to orient the faces in orient mode, besides\n"
+"getting all the faces to be the same color.  To do this "
+"one has to get the lines to be oriented in\n"
+"the same direction, this only matters with center "
+"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
+"corner or edge).  This does add complexity so there are "
+"2 sets of records.\n"
+"\n"
+"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad 2, 3) "
+"to change modes to Period 2, Period 3, or Both.\n"
+"\n"
+"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
+"is disabled here if sticky mode is on).\n"
+"\"Sticky\" and \"Period 2\" turning allows only the edges to "
+"turn, and the 2 center rows turn together. It is as if\n"
+"the middle cut of the three cuts did not exist.\n"
+"\"Sticky\" and \"Period 3\" turning allows only the faces to "
+"turn, it is as if the middle cut of the three cuts\n"
+"did not exist.\n"
+"Beware, the \"Sticky\" mode is a hack and much could be done "
+"to improve its look.\n"
+"\n"
+"Press \"S\" or \"s\" keys to start auto-solver.  Only works on "
+"1x1x1, 2x2x2, and 3x3x3 pyrmaminxs in Period 3 mode.\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Pyraminx as:\n"
+"  /    Counterclockwise\n"
+"  8 9  Up, Upper Right\n"
+"  ^\n"
+"4<5>6  Left, Clockwise, Right\n"
+"  v\n"
+"1 2    Lower Left, Down\n"
+"Use the shift keys to access \"Period 3\" turns from "
+"\"Both\" mode, otherwise it assumes \"Period 2\" turning.\n"
+"Faces and points turn in \"Period 3\" and edges (2 points) "
+"turn in \"Period 2\".\n"
+"\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys to move the whole tetrahedron.  This is not\n"
+"recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"James G. Nourse, The Simple Solutions to Cubic Puzzles, "
-	"Bantam Books, New York, 1981. pp 8-15.\n"
-	"Tom Werneck, Mastering the Magic Pyramid, Evans Brothers "
-	"Limited, London, 1981. pp 109-111.\n"
-	"Douglas R. Hofstadter, Beyond Rubik's Cube: spheres, pyramids, "
-	"dodecahedrons and God knows what else, Scientific American,\n"
-	"July 1982, pp 16-31.\n"
-	"John Ewing & Czes Kosniowski, Puzzle it Out: Cubes Groups and "
-	"Puzzles, Cambridge University Press, New York, 1982, pp 60-61.\n"
-	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"James G. Nourse, The Simple Solutions to Cubic Puzzles, "
+"Bantam Books, New York, 1981. pp 8-15.\n"
+"Tom Werneck, Mastering the Magic Pyramid, Evans Brothers "
+"Limited, London, 1981. pp 109-111.\n"
+"Douglas R. Hofstadter, Beyond Rubik's Cube: spheres, pyramids, "
+"dodecahedrons and God knows what else, Scientific American,\n"
+"July 1982, pp 16-31.\n"
+"John Ewing & Czes Kosniowski, Puzzle it Out: Cubes Groups and "
+"Puzzles, Cambridge University Press, New York, 1982, pp 60-61.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, only implemented for size < 4 where "
-	"period = 3.\n"
+"Auto-solver: sorry, only implemented for size < 4 where "
+"period = 3.\n"
 };
 
 #ifndef SCOREFILE
@@ -521,8 +520,8 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 		(void) strncpy(pyraminxRecord[i][j][k].name, userNameDsp,
 			USERNAMELEN);
 		if (size < 4 || mode == PERIOD2 || (orient &&
-			       (counter < pyraminxRecord[i][!j][k].score ||
-			       pyraminxRecord[i][!j][k].score <= NEVER))) {
+				(counter < pyraminxRecord[i][!j][k].score ||
+				pyraminxRecord[i][!j][k].score <= NEVER))) {
 			pyraminxRecord[i][!j][k].score = counter;
 			(void) strncpy(pyraminxRecord[i][!j][k].name, userNameDsp,
 				USERNAMELEN);
@@ -613,7 +612,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1130,15 +1135,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1201,8 +1206,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
