@@ -348,7 +348,7 @@ Boolean
 CheckSolved(const RubikWidget w, Boolean rotation)
 {
 	int         face, position;
-	RubikLoc    test;
+	RubikLoc    test = {0, FALSE};
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < sizeFace(w, face); position++) {
@@ -995,6 +995,9 @@ GetPieces(RubikWidget w)
 	(void) fscanf(fp, "%d", &moves);
 	ScanStartPosition(fp, w);
 	SetRubik(w, RUBIK_RESTORE);
+#ifdef WINVER
+	SetStartPosition(w);
+#endif
 	ScanMoves(fp, w, moves);
 	(void) fclose(fp);
 	(void) printf("%s: sizex %d, sizey %d, sizez %d, orient %d, practice %d, moves %d.\n",
@@ -1081,6 +1084,9 @@ UndoPieces(RubikWidget w)
 		SetRubikMove(w, RUBIK_UNDO, face, position, direction,
 			MoveAllPieces(w, face, position, direction, control,
 			DOUBLE), DOUBLE);
+		if (!control && CheckSolved(w, w->rubik.orient)) {
+			SetRubik(w, RUBIK_SOLVED);
+		}
 	}
 }
 
