@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -35,51 +35,51 @@
  ***********************************************************************/
 
 #ifndef WINVER
-#define XtNselectCallback ((char *) "selectCallback")
-#define XtNuserName ((char *) "userName")
-#define XtNscoreFile ((char *) "scoreFile")
-#define XtNsizex ((char *) "sizex")
-#define XtNsizey ((char *) "sizey")
-#define XtNsizez ((char *) "sizez")
-#define XtNorient ((char *) "orient")
 #define XtNmono ((char *) "mono")
 #define XtNreverse ((char *) "reverse")
-#define XtNdelay ((char *) "delay")
-#define XtNface ((char *) "face")
-#define XtNpos ((char *) "pos")
-#define XtNdirection ((char *) "direction")
-#define XtNcontrol ((char *) "control")
-#define XtNfast ((char *) "fast")
-#define XtNpractice ((char *) "practice")
-#define XtNstart ((char *) "start")
-#define XtNcheat ((char *) "cheat")
-#define XtNmenu ((char *) "menu")
 #define XtNframeColor ((char *) "frameColor")
-#define XtNpieceBorder ((char *) "pieceBorder")
 #define XtNfaceColor0 ((char *) "faceColor0")
 #define XtNfaceColor1 ((char *) "faceColor1")
 #define XtNfaceColor2 ((char *) "faceColor2")
 #define XtNfaceColor3 ((char *) "faceColor3")
 #define XtNfaceColor4 ((char *) "faceColor4")
 #define XtNfaceColor5 ((char *) "faceColor5")
+#define XtNpieceBorder ((char *) "pieceBorder")
+#define XtNdelay ((char *) "delay")
+#define XtNsizex ((char *) "sizex")
+#define XtNsizey ((char *) "sizey")
+#define XtNsizez ((char *) "sizez")
+#define XtNorient ((char *) "orient")
+#define XtNpractice ((char *) "practice")
+#define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNscoreOnly ((char *) "scoreOnly")
 #define XtNversionOnly ((char *) "versionOnly")
-#define XtCUserName ((char *) "UserName")
-#define XtCScoreFile ((char *) "ScoreFile")
+#define XtNmenu ((char *) "menu")
+#define XtNstart ((char *) "start")
+#define XtNcheat ((char *) "cheat")
+#define XtNface ((char *) "face")
+#define XtNpos ((char *) "position")
+#define XtNdirection ((char *) "direction")
+#define XtNcontrol ((char *) "control")
+#define XtNfast ((char *) "fast")
+#define XtNselectCallback ((char *) "selectCallback")
+#define XtCMono ((char *) "Mono")
+#define XtCReverse ((char *) "Reverse")
+#define XtCDelay ((char *) "Delay")
 #define XtCSizeX ((char *) "SizeX")
 #define XtCSizeY ((char *) "SizeY")
 #define XtCSizeZ ((char *) "SizeZ")
 #define XtCOrient ((char *) "Orient")
-#define XtCMono ((char *) "Mono")
-#define XtCReverse ((char *) "Reverse")
-#define XtCDelay ((char *) "Delay")
 #define XtCPractice ((char *) "Practice")
+#define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
+#define XtCMenu ((char *) "Menu")
 #define XtCFace ((char *) "Face")
-#define XtCPos ((char *) "Pos")
+#define XtCPos ((char *) "Position")
 #define XtCDirection ((char *) "Direction")
 #define XtCControl ((char *) "Control")
 #define XtCFast ((char *) "Fast")
-#define XtCMenu ((char *) "Menu")
 
 typedef struct _RubikClassRec *RubikWidgetClass;
 
