@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -150,12 +150,18 @@ static XtActionsRec actionsListRubik3D[] =
 
 static XtResource resourcesRubik3D[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(RubikWidget, rubik.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(RubikWidget, rubik.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(RubikWidget, core.width),
+	 XtRString, (caddr_t) "250"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(RubikWidget, core.height),
+	 XtRString, (caddr_t) "400"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -165,9 +171,6 @@ static XtResource resourcesRubik3D[] =
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
-	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(RubikWidget, rubik.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[0]),
 	 XtRString, (caddr_t) "red"},
@@ -186,12 +189,15 @@ static XtResource resourcesRubik3D[] =
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[5]),
 	 XtRString, (caddr_t) "blue"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(RubikWidget, core.width),
-	 XtRString, (caddr_t) "250"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(RubikWidget, core.height),
-	 XtRString, (caddr_t) "400"},
+	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(RubikWidget, rubik.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
+	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
+	 XtOffset(RubikWidget, rubik.delay),
+	 XtRString, (caddr_t) "10"},
+	{XtNfont, XtCFont, XtRString, sizeof (String),
+         XtOffset(RubikWidget, rubik.font),
+         XtRString, (caddr_t) "9x15bold"},
 	{XtNsizex, XtCSizeX, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.sizex),
 	 XtRString, (caddr_t) "3"},	/* DEFAULTFACETS */
@@ -204,15 +210,30 @@ static XtResource resourcesRubik3D[] =
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.orient),
 	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.mono),
+	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.practice),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.scoreFile),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.reverse),
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
+	 XtOffset(RubikWidget, rubik.menu),
+	 XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.cheat),
 	 XtRString, (caddr_t) "FALSE"},
-	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
-	 XtOffset(RubikWidget, rubik.delay),
-	 XtRString, (caddr_t) "10"},
 	{XtNface, XtCFace, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.currentFace),
 	 XtRString, (caddr_t) "-1"},
@@ -228,27 +249,6 @@ static XtResource resourcesRubik3D[] =
 	{XtNfast, XtCFast, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.currentFast),
 	 XtRString, (caddr_t) "1"},
-	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.practice),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNfont, XtCFont, XtRString, sizeof (String),
-         XtOffset(RubikWidget, rubik.font),
-         XtRString, (caddr_t) "9x15bold"},
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.cheat),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.scoreOnly),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(RubikWidget, rubik.versionOnly),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
-	 XtOffset(RubikWidget, rubik.menu),
-	 XtRString, (caddr_t) "-1"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(RubikWidget, rubik.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -548,7 +548,7 @@ void
 DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 {
 	GC          faceGC, borderGC;
-	int         x, y, dx, dy, i, j, sizeOfRow;
+	int         x = 0, y = 0, dx = 0, dy = 0, i, j, sizeOfRow;
 
 	sizeOfRow = sizeRow((RubikWidget) w, face);
 	i = position % sizeOfRow;
