@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -94,145 +94,145 @@ static RubikRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Rubik Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Rubik Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}]\n"
-	"\t[-size{x|y|z} {int}] [-[no]orient] [-[no]practice]\n"
-	"\t[-delay msecs] [-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-face{0|1|2|3|4|5} {color}] [-{border|bd} {color}]\n"
+"[-delay msecs] [-{font|fn} {fontname}]\n"
+"[-size{x|y|z} {int}] [-[no]orient] [-[no]practice]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original puzzle  has 9 squares per face  (size = 3).  "
-	"The puzzle was  designed by Erno Rubik and called the\n"
-	"Rubik's Cube.  This has 8!*12!*3^8*2^12/12 or 4.3 * 10^19 "
-	"different combinations.\n"
-	"The Pocket Cube  has 4 squares per face  (size = 2) also "
-	"designed by  Erno Rubik.  This has 7!*3^6 or 3,674,160\n"
-	"different combinations.\n"
-	"Rubik's Revenge has 16 squares per face (size = 4) also "
-	"designed by Erno Rubik.  This has 7!*3^6*24!*24!/(4!)^6\n"
-	"or 7.4 * 10^46 different combinations.\n"
-	"5x5x5 Cube.  This has 8!*12!*3^7*2^10*(24!)^3/(4!)^12 "
-	"or 2.83 * 10^74 different combinations.\n"
-	"There is also the Magic Domino 3x3x2 cube which has "
-	"(8!)^2/4 or 406,425,600 combinations.\n"
-	"A physical 6x6x6 cube is possible but to my knowledge no "
-	"one has been too successful in building one.  7x7x7 is\n"
-	"also possible, but here one  must make the center most "
-	"cubes smaller than the  outside cubes, so the corners do\n"
-	"not fall off when turned.\n"
+"The original puzzle  has 9 squares per face  (size = 3).  "
+"The puzzle was  designed by Erno Rubik and called the\n"
+"Rubik's Cube.  This has 8!*12!*3^8*2^12/12 or 4.3 * 10^19 "
+"different combinations.\n"
+"The Pocket Cube  has 4 squares per face  (size = 2) also "
+"designed by  Erno Rubik.  This has 7!*3^6 or 3,674,160\n"
+"different combinations.\n"
+"Rubik's Revenge has 16 squares per face (size = 4) also "
+"designed by Erno Rubik.  This has 7!*3^6*24!*24!/(4!)^6\n"
+"or 7.4 * 10^46 different combinations.\n"
+"5x5x5 Cube.  This has 8!*12!*3^7*2^10*(24!)^3/(4!)^12 "
+"or 2.83 * 10^74 different combinations.\n"
+"There is also the Magic Domino 3x3x2 cube which has "
+"(8!)^2/4 or 406,425,600 combinations.\n"
+"A physical 6x6x6 cube is possible but to my knowledge no "
+"one has been too successful in building one.  7x7x7 is\n"
+"also possible, but here one  must make the center most "
+"cubes smaller than the  outside cubes, so the corners do\n"
+"not fall off when turned.\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece on the same face and\n"
-	"in the same row.  The pieces will then turn towards "
-	"where the mouse button was released.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode  (in practice mode\n"
-	"the record should say \"practice\").  This is good for "
-	"learning moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of \"cubies\".\n"
-	"\n"
-	"Press \"D\" or \"d\" keys to decrease the number of \"cubies\".\n"
-	"\n"
-	"Press \"x\" key to increase the number of \"cubies\" along "
-	"the x axis.\n"
-	"\n"
-	"Press \"X\" key to decrease the number of \"cubies\" along "
-	"the x axis.\n"
-	"\n"
-	"Press \"y\" key to increase the number of \"cubies\" along "
-	"the y axis.\n"
-	"\n"
-	"Press \"Y\" key to decrease the number of \"cubies\" along "
-	"the y axis.\n"
-	"\n"
-	"Press \"z\" key to increase the number of \"cubies\" along "
-	"the z axis.\n"
-	"\n"
-	"Press \"Z\" key to decrease the number of \"cubies\" along "
-	"the z axis.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
-	"has to  orient the faces in orient mode, besides\n"
-	"getting all  the faces to be the  same color.  To do this "
-	"one  has to get the  lines to be  oriented in\n"
-	"the same direction,  this only matters  with center "
-	"\"cubies\",  if at all (i.e.  those \"cubies\" not on a\n"
-	"corner or edge).  This does add complexity so there are "
-	"2 sets of records.\n"
-	"\n"
-	"Press \"S\" or \"s\" keys to start auto-solver.  Only works "
-	"on 1x1x1, 2x2x2, and 3x3x3 cubes (3x3x3 cube in\n"
-	"non-orient mode).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"mouse clicks.\n"
-	"Key pad is defined for Rubik2d as:\n"
-	"  /    Counterclockwise\n"
-	"  8    Up\n"
-	"  ^\n"
-	"4<5>6  Left, Clockwise, Right\n"
-	"  v\n"
-	"  2    Down\n"
-	"Key pad for Rubik3d, use must use your intuition (is this "
-	"a cop out or what?).  The key pad  is defined\n"
-	"differently  depending on which side  of the cube your mouse "
-	"is pointing at.  One thing  that stays the\n"
-	"same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
-	"\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys  to move the whole cube.  This is\n"
-	"not recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece on the same face and\n"
+"in the same row.  The pieces will then turn towards "
+"where the mouse button was released.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode  (in practice mode\n"
+"the record should say \"practice\").  This is good for "
+"learning moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of \"cubies\".\n"
+"\n"
+"Press \"D\" or \"d\" keys to decrease the number of \"cubies\".\n"
+"\n"
+"Press \"x\" key to increase the number of \"cubies\" along "
+"the x axis.\n"
+"\n"
+"Press \"X\" key to decrease the number of \"cubies\" along "
+"the x axis.\n"
+"\n"
+"Press \"y\" key to increase the number of \"cubies\" along "
+"the y axis.\n"
+"\n"
+"Press \"Y\" key to decrease the number of \"cubies\" along "
+"the y axis.\n"
+"\n"
+"Press \"z\" key to increase the number of \"cubies\" along "
+"the z axis.\n"
+"\n"
+"Press \"Z\" key to decrease the number of \"cubies\" along "
+"the z axis.\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
+"has to  orient the faces in orient mode, besides\n"
+"getting all  the faces to be the  same color.  To do this "
+"one  has to get the  lines to be  oriented in\n"
+"the same direction,  this only matters  with center "
+"\"cubies\",  if at all (i.e.  those \"cubies\" not on a\n"
+"corner or edge).  This does add complexity so there are "
+"2 sets of records.\n"
+"\n"
+"Press \"S\" or \"s\" keys to start auto-solver.  Only works "
+"on 1x1x1, 2x2x2, and 3x3x3 cubes (3x3x3 cube in\n"
+"non-orient mode).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Rubik2d as:\n"
+"  /    Counterclockwise\n"
+"  8    Up\n"
+"  ^\n"
+"4<5>6  Left, Clockwise, Right\n"
+"  v\n"
+"  2    Down\n"
+"Key pad for Rubik3d, use must use your intuition (is this "
+"a cop out or what?).  The key pad  is defined\n"
+"differently  depending on which side  of the cube your mouse "
+"is pointing at.  One thing  that stays the\n"
+"same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
+"\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys  to move the whole cube.  This is\n"
+"not recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"Inside Rubik's Cube and Beyond by Christoph Bandelow, "
-	"Birkhauser, 1982 pp 44, 45, 88, 89.\n"
-	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
-	"The Simple Solution To Rubik's Cube, James G. Nourse, "
-	"June 1981.\n"
-	"Rubik's Cube Newsletter by Ideal Aug 1982 Vol.1 No. 2.\n"
-	"Rubik's Cube The Solution, Ideal Toy Corporation, 1981.\n"
-	"Rubik's Revenge Puzzle The Solution, Ideal Toy "
-	"Corporation, 1982.\n"
+"Inside Rubik's Cube and Beyond by Christoph Bandelow, "
+"Birkhauser, 1982 pp 44, 45, 88, 89.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"The Simple Solution To Rubik's Cube, James G. Nourse, "
+"June 1981.\n"
+"Rubik's Cube Newsletter by Ideal Aug 1982 Vol.1 No. 2.\n"
+"Rubik's Cube The Solution, Ideal Toy Corporation, 1981.\n"
+"Rubik's Revenge Puzzle The Solution, Ideal Toy "
+"Corporation, 1982.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, only implemented for size nxnxn where "
-	"n < 4.\n"
+"Auto-solver: sorry, only implemented for size nxnxn where "
+"n < 4.\n"
 };
 
 #ifndef SCOREFILE
@@ -723,7 +723,13 @@ void
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1193,13 +1199,6 @@ CallbackRubik(Widget w, caddr_t clientData, rubikCallbackStruct * callData)
 					XtNcontrol, callData->control,
 					XtNfast, callData->fast,
 					XtNstart, True, NULL);
-				XtVaSetValues(w,
-					XtNface, callData->face,
-					XtNpos, callData->position,
-					XtNdirection, callData->direction,
-					XtNcontrol, callData->control,
-					XtNfast, callData->fast,
-					XtNstart, True, NULL);
 			} else {
 				movesDsp--;
 #ifdef HAVE_OPENGL
@@ -1216,12 +1215,6 @@ CallbackRubik(Widget w, caddr_t clientData, rubikCallbackStruct * callData)
 					XtNdirection, callData->direction,
 					XtNcontrol, callData->control,
 					XtNfast, callData->fast, NULL);
-				XtVaSetValues(w,
-					XtNface, callData->face,
-					XtNpos, callData->position,
-					XtNdirection, callData->direction,
-					XtNcontrol, callData->control,
-					XtNfast, callData->fast, NULL);
 			}
 			break;
 #endif
@@ -1538,15 +1531,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1608,8 +1601,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
