@@ -934,6 +934,9 @@ GetPieces(SkewbWidget w)
 	(void) fscanf(fp, "%d", &moves);
 	ScanStartPosition(fp, w);
 	SetSkewb(w, SKEWB_RESTORE);
+#ifdef WINVER
+	SetStartPosition(w);
+#endif
 	ScanMoves(fp, w, moves);
 	(void) fclose(fp);
 	(void) printf("%s: orient %d, practice %d, moves %d.\n",
@@ -1034,6 +1037,9 @@ UndoPieces(SkewbWidget w)
 			}
 			MovePieces(w, face, position, direction);
 			SetSkewbMove(w, SKEWB_UNDO, face, position, direction);
+			if (CheckSolved(w)) {
+				SetSkewb(w, SKEWB_SOLVED);
+			}
 		}
 	}
 }
