@@ -37,9 +37,9 @@ typedef struct _Skewb2DClassPart {
 } Skewb2DClassPart;
 
 typedef struct _Skewb2DClassRec {
-	CoreClassPart core_class;
-	SkewbClassPart skewb_class;
-	Skewb2DClassPart skewb2d_class;
+	CoreClassPart coreClass;
+	SkewbClassPart skewbClass;
+	Skewb2DClassPart skewb2dClass;
 } Skewb2DClassRec;
 
 extern Skewb2DClassRec skewb2dClassRec;
