@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -140,12 +140,18 @@ static XtActionsRec actionsListSkewb3D[] =
 
 static XtResource resourcesSkewb3D[] =
 {
-	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(SkewbWidget, skewb.userName),
-	 XtRString, (caddr_t) ""},
-	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
-	 XtOffset(SkewbWidget, skewb.scoreFile),
-	 XtRString, (caddr_t) ""},
+	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+	 XtOffset(SkewbWidget, core.width),
+	 XtRString, (caddr_t) "250"},
+	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+	 XtOffset(SkewbWidget, core.height),
+	 XtRString, (caddr_t) "400"},
+	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.mono),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.reverse),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -155,9 +161,6 @@ static XtResource resourcesSkewb3D[] =
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
-	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(SkewbWidget, skewb.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[0]),
 	 XtRString, (caddr_t) "red"},
@@ -176,20 +179,38 @@ static XtResource resourcesSkewb3D[] =
 	{XtNfaceColor5, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.faceName[5]),
 	 XtRString, (caddr_t) "yellow"},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(SkewbWidget, core.width),
-	 XtRString, (caddr_t) "250"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(SkewbWidget, core.height),
-	 XtRString, (caddr_t) "400"},
+	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(SkewbWidget, skewb.borderColor),
+	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
+	{XtNfont, XtCFont, XtRString, sizeof (String),
+	 XtOffset(SkewbWidget, skewb.font),
+	 XtRString, (caddr_t) "9x15bold"},
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.orient),
 	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.mono),
+	{XtNpractice, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.practice),
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(SkewbWidget, skewb.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(SkewbWidget, skewb.scoreFile),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.scoreOnly),
 	 XtRString, (caddr_t) "FALSE"},
-	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.reverse),
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
+         XtOffset(SkewbWidget, skewb.menu),
+         XtRString, (caddr_t) "-1"},
+	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.started),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.cheat),
 	 XtRString, (caddr_t) "FALSE"},
 	{XtNface, XtCFace, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.currentFace),
@@ -200,26 +221,6 @@ static XtResource resourcesSkewb3D[] =
 	{XtNdirection, XtCDirection, XtRInt, sizeof (int),
 	 XtOffset(SkewbWidget, skewb.currentDirection),
 	 XtRString, (caddr_t) "-1"},
-	{XtNpractice, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.practice),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTPRACTICE */
-	{XtNfont, XtCFont, XtRString, sizeof (String),
-	 XtOffset(SkewbWidget, skewb.font),
-	 XtRString, (caddr_t) "9x15bold"},
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.started),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.cheat),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.scoreOnly),
-	 XtRString, (caddr_t) "FALSE"},
-	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(SkewbWidget, skewb.versionOnly),
-	 XtRString, (caddr_t) "FALSE"},{XtNmenu, XtCMenu, XtRInt, sizeof (int),
-         XtOffset(SkewbWidget, skewb.menu),
-         XtRString, (caddr_t) "-1"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(SkewbWidget, skewb.select),
 	 XtRCallback, (caddr_t) NULL}
@@ -432,7 +433,7 @@ void
 DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
 {
 	GC          faceGC, borderGC;
-	int         side, dx, dy, letterX, letterY;
+	int         side = 0, dx, dy, letterX, letterY;
 
 	MapTo3D(w, face, position, &side);
 	CubeOffset3D(w, face, side, &dx, &dy);
