@@ -37,9 +37,9 @@ typedef struct _Skewb3DClassPart {
 } Skewb3DClassPart;
 
 typedef struct _Skewb3DClassRec {
-	CoreClassPart core_class;
-	SkewbClassPart skewb_class;
-	Skewb3DClassPart skewb3d_class;
+	CoreClassPart coreClass;
+	SkewbClassPart skewbClass;
+	Skewb3DClassPart skewb3dClass;
 } Skewb3DClassRec;
 
 extern Skewb3DClassRec skewb3dClassRec;
