@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -93,133 +93,132 @@ static SkewbRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Skewb Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Skewb Version 7.2.1\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
-	"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n"
-	"\t[-userName {string}] [-scoreFile {filename}] [-scores]\n"
-	"\t[-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-face{0|1|2|3|4|5} {color}] [-{border|bd} {color}]\n"
+"[-{font|fn} {fontname}] [-[no]orient] [-[no]practice]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"The original puzzle has each face cut by a diamond, so "
-	"that there are 5 pieces,  4 corner pieces and\n"
-	"one diamond piece in the center.  This was designed by "
-	"Uwe Meffert and called the Pyraminx Cube.  Douglas\n"
-	"Hofstadter later coined it a Skewb and it stuck.  The "
-	"puzzle has period 3 turning (i.e. each half turns\n"
-	"with 120 degree intervals).  The Skewb has  2^5*3^8*6!/2^6 "
-	"or 3,149,280  different combinations (with\n"
-	"centers oriented 2^5*3^8*6!/2 or 100,766,960 different "
-	"combinations).\n"
-	"More recently, Disney released Mickey's Challenge, its "
-	"a spherical skewb with a pretty good internal\n"
-	"mechanism.  Mickey's challenge has 2^5*3^8*6!/36 "
-	"5,598,720 visually different combinations).  It also\n"
-	"comes with a pretty neat book.  Also released "
-	"is the Creative Puzzle Ball or Meffert's Challenge which\n"
-	"has 4 rings in different colors.\n"
-	"Mach Balls of the Hungarian Gyula Mach are similar "
-	"but they do not have a ratchet mechanism and do not\n"
-	"turn as easily or smoothly.  One must match the 12 "
-	"different symbols of 4 each  at the 12 intersection\n"
-	"points.\n"
+"The original puzzle has each face cut by a diamond, so "
+"that there are 5 pieces,  4 corner pieces and\n"
+"one diamond piece in the center.  This was designed by "
+"Uwe Meffert and called the Pyraminx Cube.  Douglas\n"
+"Hofstadter later coined it a Skewb and it stuck.  The "
+"puzzle has period 3 turning (i.e. each half turns\n"
+"with 120 degree intervals).  The Skewb has  2^5*3^8*6!/2^6 "
+"or 3,149,280  different combinations (with\n"
+"centers oriented 2^5*3^8*6!/2 or 100,766,960 different "
+"combinations).\n"
+"More recently, Disney released Mickey's Challenge, its "
+"a spherical skewb with a pretty good internal\n"
+"mechanism.  Mickey's challenge has 2^5*3^8*6!/36 "
+"5,598,720 visually different combinations).  It also\n"
+"comes with a pretty neat book.  Also released "
+"is the Creative Puzzle Ball or Meffert's Challenge which\n"
+"has 4 rings in different colors.\n"
+"Mach Balls of the Hungarian Gyula Mach are similar "
+"but they do not have a ratchet mechanism and do not\n"
+"turn as easily or smoothly.  One must match the 12 "
+"different symbols of 4 each  at the 12 intersection\n"
+"points.\n"
 };
 
 static const char featuresHelp[] = {
-	"Press \"mouse-left\" button to move a piece.  Release "
-	"\"mouse-left\" button on a piece  on the same face.\n"
-	"(Clicks on diamonds are ignored).  The pieces will then "
-	"turn towards where the mouse button was released.\n"
-	"\n"
-	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle the practice mode  (in practice mode the\n"
-	"the record should say \"practice\").  This is good for "
-	"learning moves and experimenting.\n"
-	"\n"
-	"Click \"mouse-right\" button,  or press \"R\" or \"r\" "
-	"keys,  to randomize the puzzle  (this must be done first\n"
-	"to set a new record).\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
-	"has  to orient the faces  in orient mode,  besides\n"
-	"getting  all the faces to be the  same color.  To do this "
-	"one has to get the lines to be  oriented in the\n"
-	"same direction,  this only matters with  center diamond "
-	"piece.  This does add complexity  so there are 2\n"
-	"sets of records.\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"mouse clicks.\n"
-	"Key pad is defined for Skewb2d as:\n"
-	"  /    Counterclockwise\n"
-	"7 8 9  Upper Left, Up, Upper Right\n"
-	"  ^\n"
-	"4<5>6  Left, Clockwise, Right\n"
-	"  v\n"
-	"1 2 3  Lower Left, Down, Lower Right\n"
-	"Note: Top, Left, Right, and Down only work when the "
-	"control key is pressed and there is no analog for\n"
-	"Skewb3d.\n"
-	"If the mouse is on a diamond, the above keys will not "
-	"move cube because the move is ambiguous.  Also\n"
-	"if the mouse is on a triangle, not all the keys will "
-	"function because the puzzle will only rotate on the\n"
-	"cuts, i.e. a triangle with a Upper Left - Lower Right "
-	"cut will rotate only Upper Left & Lower Right, a\n"
-	"triangle with a Upper Right - Lower Left cut will rotate "
-	"only Upper Right & Lower Left.  Therefore, a\n"
-	"triangle can only move tangential to the center of "
-	"the face. No doubt this is confusing, but the physical\n"
-	"skewb is the same way. In fact, that is part of its appeal.\n"
-	"Key pad for Skewb3d, use must use your intuition (is this "
-	"a cop out or what?).  The key pad is defined\n"
-	"differently depending on which side of the cube your mouse "
-	"is pointing at.  One thing that stays the\n"
-	"same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
-	"\n"
-	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys  to move the whole cube.  This is\n"
-	"not recorded as a turn.\n"
+"Press \"mouse-left\" button to move a piece.  Release "
+"\"mouse-left\" button on a piece  on the same face.\n"
+"(Clicks on diamonds are ignored).  The pieces will then "
+"turn towards where the mouse button was released.\n"
+"\n"
+"Click \"mouse-center\" button, or press \"P\" or \"p\" "
+"keys, to toggle the practice mode  (in practice mode the\n"
+"the record should say \"practice\").  This is good for "
+"learning moves and experimenting.\n"
+"\n"
+"Click \"mouse-right\" button,  or press \"R\" or \"r\" "
+"keys,  to randomize the puzzle  (this must be done first\n"
+"to set a new record).\n"
+"\n"
+"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
+"has  to orient the faces  in orient mode,  besides\n"
+"getting  all the faces to be the  same color.  To do this "
+"one has to get the lines to be  oriented in the\n"
+"same direction,  this only matters with  center diamond "
+"piece.  This does add complexity  so there are 2\n"
+"sets of records.\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Skewb2d as:\n"
+"  /    Counterclockwise\n"
+"7 8 9  Upper Left, Up, Upper Right\n"
+"  ^\n"
+"4<5>6  Left, Clockwise, Right\n"
+"  v\n"
+"1 2 3  Lower Left, Down, Lower Right\n"
+"Note: Top, Left, Right, and Down only work when the "
+"control key is pressed and there is no analog for\n"
+"Skewb3d.\n"
+"If the mouse is on a diamond, the above keys will not "
+"move cube because the move is ambiguous.  Also\n"
+"if the mouse is on a triangle, not all the keys will "
+"function because the puzzle will only rotate on the\n"
+"cuts, i.e. a triangle with a Upper Left - Lower Right "
+"cut will rotate only Upper Left & Lower Right, a\n"
+"triangle with a Upper Right - Lower Left cut will rotate "
+"only Upper Right & Lower Left.  Therefore, a\n"
+"triangle can only move tangential to the center of "
+"the face. No doubt this is confusing, but the physical\n"
+"skewb is the same way. In fact, that is part of its appeal.\n"
+"Key pad for Skewb3d, use must use your intuition (is this "
+"a cop out or what?).  The key pad is defined\n"
+"differently depending on which side of the cube your mouse "
+"is pointing at.  One thing that stays the\n"
+"same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
+"\n"
+"Use the control key and the left mouse button, keypad, or "
+"arrow keys  to move the whole cube.  This is\n"
+"not recorded as a turn.\n"
 };
 
 static const char referencesHelp[] = {
-	"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
-	"God knows what else by Douglas\n"
-	"R. Hofstadter, Scientific American, July 1982, pp 16-31.\n"
-	"Mickey's Challenge by Christoph Bandelow.\n"
-	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
+"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
+"God knows what else by Douglas\n"
+"R. Hofstadter, Scientific American, July 1982, pp 16-31.\n"
+"Mickey's Challenge by Christoph Bandelow.\n"
+"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -364,7 +363,7 @@ ReadRecords(void)
 	for (orient = 0; orient < 2; orient++) {
 		(void) fscanf(fp, "%d %s\n", &n, userName);
 		if (n <= skewbRecord[orient].score ||
-		    skewbRecord[orient].score <= NEVER) {
+				skewbRecord[orient].score <= NEVER) {
 			skewbRecord[orient].score = n;
 			(void) strncpy(skewbRecord[orient].name, userName,
 				USERNAMELEN);
@@ -618,7 +617,13 @@ void
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -1233,15 +1238,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -1303,8 +1308,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
