@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -34,64 +34,64 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Threed Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
-	"Originally written by Thomas W. Olsen "
-	"in the \"The C Users Journal\".\n"
+"Threed Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Originally written by Thomas W. Olsen "
+"in the \"The C Users Journal\".\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]][-fg {color}] [-bg {color}]\n"
-	"\t[-[no]surface] [-object {int}] [-x {int}] [-y {int}] [-z {int}]\n"
-	"\t[-theta {int}] [-phi {int}] [psi {int}] [-white {color}]\n"
-	"\t[-[lt|dk]gray {color}] [-black {color}] [-another {color}]\n"
-	"\t[-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-{foreground|fg} {color}]\n"
+"[-{background|bg} {color}] [-frame {color}]\n"
+"[-white {color}] [-[lt|dk]gray {color}] [-black {color}]\n"
+"[-another {color}] [-{border|bd} {color}] [-[no]surface]\n"
+"[-object {int}] [-x {int}] [-y {int}] [-z {int}]\n"
+"[-theta {int}] [-phi {int}] [psi {int}] [-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"A simple 3D viewer."
+"A simple 3D viewer."
 };
 
 static const char featuresHelp[] = {
-	"Press \"L\" or \"l\" keys to move object left.\n"
-	"Press \"R\" or \"r\" keys to move object right.\n"
-	"Press \"U\" or \"u\" keys to move object up.\n"
-	"Press \"D\" or \"d\" keys to move object down.\n"
-	"Press \"I\" or \"i\" keys to move object in.\n"
-	"Press \"O\" or \"o\" keys to move object out.\n"
-	"Press \"S\" or \"s\" keys to change surface.\n"
-	"Press \"B\" or \"b\" keys to change object.\n"
-	"Press \"Esc\" key to hide program.\n"
-	"Press \"Q\", \"fBq\", or \"CTRL-C\" keys kill program.\n"
-	"Use the key pad, \"R\" keys, or arrow keys to rotate object.\n"
-	"Key pad is defined for Threed as:\n"
-	"  /     Counterclockwise\n"
-	"  8     Up\n"
-	"  ^\n"
-	"4<5>6   Left, Clockwise, Right\n"
-	"  v\n"
-	"  2     Down\n"
-	"I debated releasing this, since it needs some work."
-	"Also, I figured there was other 3D viewers out there.\n"
-        "Well, this one is real simple, it only uses the X"
-        "libs, so it might be useful to someone out there\n"
-	"If you have any improvements to make, let me know.\n"
-	"In the sample data, Cubes and F16 are big, so the "
-	"polyhedrons are scaled up to them in the data file.\n"
+"Press \"L\" or \"l\" keys to move object left.\n"
+"Press \"R\" or \"r\" keys to move object right.\n"
+"Press \"U\" or \"u\" keys to move object up.\n"
+"Press \"D\" or \"d\" keys to move object down.\n"
+"Press \"I\" or \"i\" keys to move object in.\n"
+"Press \"O\" or \"o\" keys to move object out.\n"
+"Press \"S\" or \"s\" keys to change surface.\n"
+"Press \"B\" or \"b\" keys to change object.\n"
+"Press \"Esc\" key to hide program.\n"
+"Press \"Q\", \"fBq\", or \"CTRL-C\" keys kill program.\n"
+"Use the key pad or arrow keys to rotate object without the mouse.\n"
+"Key pad is defined for Threed as:\n"
+"  /     Counterclockwise\n"
+"  8     Up\n"
+"  ^\n"
+"4<5>6   Left, Clockwise, Right\n"
+"  v\n"
+"  2     Down\n"
+"I debated releasing this, since it needs some work."
+"Also, I figured there was other 3D viewers out there.\n"
+"Well, this one is real simple, it only uses the X"
+"libs, so it might be useful to someone out there\n"
+"If you have any improvements to make, let me know.\n"
+"In the sample data, Cubes and F16 are big, so the "
+"polyhedrons are scaled up to them in the data file.\n"
 };
 
 static const char referencesHelp[] = {
-	"Original code by\n"
-	"Thomas W. Olsen \"The C Users Journal\".\n"
-	"Andre LaMothe \"Black Art of 3D Game Programming\".\n"
-	"Arash Partow \"http://www.partow.net\".\n"
-	
+"Original code by\n"
+"Thomas W. Olsen \"The C Users Journal\".\n"
+"Andre LaMothe \"Black Art of 3D Game Programming\".\n"
+"Arash Partow \"http://www.partow.net\".\n"
 };
 #endif
 
@@ -619,17 +619,31 @@ static Widget topLevel, threed;
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
 static XrmOptionDescRec options[] = {
-	{(char *) "-fg", (char *) "*cubes.Foreground", XrmoptionSepArg, NULL},
-	{(char *) "-bd", (char *) "*cubes.Foreground", XrmoptionSepArg, NULL},
-	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
-	{(char *) "-foreground", (char *) "*cubes.Foreground", XrmoptionSepArg, NULL},
+	{(char *) "-foreground", (char *) "*threed.Foreground", XrmoptionSepArg, NULL},
+	{(char *) "-fg", (char *) "*threed.Foreground", XrmoptionSepArg, NULL},
 	{(char *) "-background", (char *) "*Background", XrmoptionSepArg, NULL},
+	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
+	{(char *) "-frame", (char *) "*threed.frameColor", XrmoptionSepArg, NULL},
+	{(char *) "-white", (char *) "*threed.whiteBrush", XrmoptionSepArg, NULL},
+	{(char *) "-ltgray", (char *) "*threed.ltgrayBrush", XrmoptionSepArg, NULL},
+	{(char *) "-gray", (char *) "*threed.grayBrush", XrmoptionSepArg, NULL},
+	{(char *) "-dkgray", (char *) "*threed.dkgrayBrush", XrmoptionSepArg, NULL},
+	{(char *) "-black", (char *) "*threed.blackBrush", XrmoptionSepArg, NULL},
+	{(char *) "-another", (char *) "*threed.anotherBrush", XrmoptionSepArg, NULL},
+	{(char *) "-border", (char *) "*threed.surfaceBorder", XrmoptionSepArg, NULL},
+	{(char *) "-bd", (char *) "*threed.surfaceBorder", XrmoptionSepArg, NULL},
 	{(char *) "-surface", (char *) "*threed.surface", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosurface", (char *) "*threed.surface", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-object", (char *) "*threed.object", XrmoptionSepArg, (char *) "0"},
@@ -639,12 +653,6 @@ static XrmOptionDescRec options[] = {
 	{(char *) "-theta", (char *) "*threed.angle.theta", XrmoptionSepArg, (char *) "0.0"},
 	{(char *) "-phi", (char *) "*threed.angle.phi", XrmoptionSepArg, (char *) "0.0"},
 	{(char *) "-psi", (char *) "*threed.angle.psi", XrmoptionSepArg, (char *) "0.0"},
-	{(char *) "-white", (char *) "*threed.whiteBrush", XrmoptionSepArg, NULL},
-	{(char *) "-ltgray", (char *) "*threed.ltgrayBrush", XrmoptionSepArg, NULL},
-	{(char *) "-gray", (char *) "*threed.grayBrush", XrmoptionSepArg, NULL},
-	{(char *) "-dkgray", (char *) "*threed.dkgrayBrush", XrmoptionSepArg, NULL},
-	{(char *) "-black", (char *) "*threed.blackBrush", XrmoptionSepArg, NULL},
-	{(char *) "-another", (char *) "*threed.anotherBrush", XrmoptionSepArg, NULL},
 	{(char *) "-version", (char *) "*threed.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
