@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -88,93 +88,92 @@ static TrianglesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-	"Triangles Version 7.1.5\n"
-	"Send bugs (reports or fixes) to the author: "
-	"David Bagley <bagleyd@tux.org>\n"
-	"The latest version is at: "
-	"http://www.tux.org/~bagleyd/puzzles.html\n"
+"Triangles Version 7.2\n"
+"Send bugs (reports or fixes) to the author: "
+"David Bagley <bagleyd@tux.org>\n"
+"The latest version is at: "
+"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
 
 static const char optionsHelp[] = {
-	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
-	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-	"\t[-{border|bd} {color}] [-tile {color}] [-size {int}]\n"
-	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
-	"\t[-[no]sound] [-bumpSound {filename}] [-base {int}]\n"
-	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
-	"\t[-scoreFile {filename}] [-scores] [-version]\n"
+"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+"[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+"[-tile {color}] [-{border|bd} {color}] [-delay msecs]\n"
+"[-[no]sound] [-bumpSound {filename}]\n"
+"[-{font|fn} {fontname}] [-size {int}] [-base {int}]\n"
+"[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+"[-version]\n"
 };
 #endif
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-	"A sliding tile puzzle.  A triangular version of the "
-	"15 puzzle which was originally made around 1879 (the 14-15\n"
-	"puzzle of Sam Loyd was made soon after).   T. R. Dawson "
-	"in Original Puzzles has a similar puzzle with 4 diamond-\n"
-	"and 6 triangular-shaped pieces.  This is easier to solve "
-	"than 15 puzzle.\n"
+"A sliding tile puzzle.  A triangular version of the "
+"15 puzzle which was originally made around 1879 (the 14-15\n"
+"puzzle of Sam Loyd was made soon after).   T. R. Dawson "
+"in Original Puzzles has a similar puzzle with 4 diamond-\n"
+"and 6 triangular-shaped pieces.  This puzzle is easier to "
+"solve than 15 puzzle.\n"
 };
 
 static const char featuresHelp[] = {
-	"Click \"mouse-left\" button to move a tile.  Clicks on "
-	"spaces, or clicks on tiles that are not in line with\n"
-	"two spaces will not move tiles.  Notice, one can move "
-	"more than  one tile at a time  by clicking on\n"
-	"the tile farthest from the spaces but still in line with the "
-	"spaces.\n"
-	"\n"
-	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
-	"keys, to randomize the puzzle.\n"
-	"\n"
-	"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
-	"\n"
-	"Press \"O\" or \"o\" keys to decrease the number of tiles.\n"
-	"\n"
-	"\"S\" or \"s\" keys reserved for the auto-solver "
-	"(not implemented).\n"
-	"\n"
-	"Press \"U\" or \"u\" keys to undo a move.\n"
-	"\n"
-	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
-	"\n"
-	"Press \"W\" or \"w\" keys to save a puzzle.\n"
-	"\n"
-	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
-	"\n"
-	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
-	"\n"
-	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
-	"\n"
-	"Press \"@\" key to toggle the sound.\n"
-	"\n"
-	"Press \"Esc\" key to hide program.\n"
-	"\n"
-	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
-	"\n"
-	"Use the key pad, \"R\" keys, or arrow keys to move without "
-	"the mouse.\n"
-	"Key pad is defined for Triangles as:\n"
-	"7   9  Upper Left, Upper Right\n"
-	"  ^\n"
-	"4< >6  Left, Right\n"
-	"  v\n"
-	"1   3  Lower Left, Lower Right\n"
+"Click \"mouse-left\" button to move a tile.  Clicks on "
+"spaces, or clicks on tiles that are not in line with\n"
+"two spaces will not move tiles.  Notice, one can move "
+"more than  one tile at a time  by clicking on\n"
+"the tile farthest from the spaces but still in line with the "
+"spaces.\n"
+"\n"
+"Click \"mouse-right\" button, or press \"R\" or \"r\" "
+"keys, to randomize the puzzle.\n"
+"\n"
+"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
+"\n"
+"Press \"O\" or \"o\" keys to decrease the number of tiles.\n"
+"\n"
+"\"S\" or \"s\" keys reserved for the auto-solver "
+"(not implemented).\n"
+"\n"
+"Press \"U\" or \"u\" keys to undo a move.\n"
+"\n"
+"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"\n"
+"Press \"W\" or \"w\" keys to save a puzzle.\n"
+"\n"
+"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+"\n"
+"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+"\n"
+"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+"\n"
+"Press \"@\" key to toggle the sound.\n"
+"\n"
+"Press \"Esc\" key to hide program.\n"
+"\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+"\n"
+"Use the key pad or arrow keys to move without the mouse.\n"
+"Key pad is defined for Triangles as:\n"
+"7   9  Upper Left, Upper Right\n"
+"  ^\n"
+"4< >6  Left, Right\n"
+"  v\n"
+"1   3  Lower Left, Lower Right\n"
 };
 
 static const char referencesHelp[] = {
-	"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
-	"Mathematics Series), Oxford University Press  1986,\n"
-	"pp 1, 148, 149.\n"
-	"Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
-	"and Solve Them),  University of Washington\n"
-	"Press, Seattle 1987, p 126, 127.\n"
+"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
+"Mathematics Series), Oxford University Press  1986,\n"
+"pp 1, 148, 149.\n"
+"Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
+"and Solve Them),  University of Washington\n"
+"Press, Seattle 1987, p 126, 127.\n"
 };
 #endif
 
 static const char solveHelp[] = {
-	"Auto-solver: sorry, not implemented.\n"
+"Auto-solver: sorry, not implemented.\n"
 };
 
 #ifndef SCOREFILE
@@ -497,7 +496,13 @@ Widget w
 #ifdef WINVER
 		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(userNameDsp, "%s", getlogin());
+		char * login = getlogin();
+
+		if (login == NULL) {
+			(void) strcpy(userNameDsp, "");
+		} else {
+			(void) sprintf(userNameDsp, "%s", login);
+		}
 		if (!strcmp(userNameDsp, "") ||
 				!strcmp(userNameDsp, "(null)") ||
 				!strcmp(userNameDsp, NOACCESS) ||
@@ -822,15 +827,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					break;
 				case IDM_DESCRIPTION:
 					(void) MessageBox(hWnd, descriptionHelp,
-					 	"Description", MB_OK);
+						"Description", MB_OK);
 					break;
 				case IDM_FEATURES:
 					(void) MessageBox(hWnd, featuresHelp,
-					 	"Features", MB_OK);
+						"Features", MB_OK);
 					break;
 				case IDM_REFERENCES:
 					(void) MessageBox(hWnd, referencesHelp,
-					 	"References", MB_OK);
+						"References", MB_OK);
 					break;
 			}
 			break;
@@ -893,8 +898,14 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 static void
 Usage(char * programName)
 {
+	unsigned int i;
+
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr, optionsHelp);
+	for (i = 0; i < strlen(optionsHelp); i++) {
+		if (i == 0 || optionsHelp[i - 1] == '\n')
+			(void) fprintf(stderr, "\t");
+		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+	}
 	exit(1);
 }
 
